/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_CHAFFVERB_HPP_
#define _HEAVY_CONTEXT_CHAFFVERB_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlCast.h"
#include "HvSignalRPole.h"
#include "HvTable.h"
#include "HvSignalLine.h"
#include "HvControlDelay.h"
#include "HvControlPack.h"
#include "HvSignalTabwrite.h"
#include "HvMath.h"
#include "HvControlVar.h"
#include "HvControlRandom.h"
#include "HvControlSystem.h"
#include "HvSignalTabread.h"
#include "HvSignalPhasor.h"
#include "HvControlTabhead.h"
#include "HvSignalDel1.h"
#include "HvControlBinop.h"
#include "HvSignalVar.h"
#include "HvControlIf.h"
#include "HvControlSlice.h"
#include "HvControlUnop.h"

class Heavy_ChaffVerb : public HeavyContext {

 public:
  Heavy_ChaffVerb(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_ChaffVerb();

  const char *getName() override { return "ChaffVerb"; }
  int getNumInputChannels() override { return 1; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        A__LFO_PERIOD = 0x1F30993F, // A__LFO_Period
        A__LFO_STEPS_SCALE__TYPE2 = 0x1A2B8E9F, // A__LFO_Steps_Scale__Type2
        A__LFO_STEPS__TYPE2 = 0xBE3344C8, // A__LFO_Steps__Type2
        A__LFO_SWITCH = 0x7369936E, // A__LFO_Switch
        A__LFO_TYPE = 0xD64CFD23, // A__LFO_type
        B__GENERAL_OFFSET = 0x51447E19, // B__General_Offset
        B__GENERAL_SCALE = 0xA10FCFC4, // B__General_Scale
        C__RANDOM_LFO_OFFSET = 0x7EFB8E46, // C__Random_LFO_Offset
        C__RANDOM_LFO_PERIOD = 0xE6223016, // C__Random_LFO_Period
        C__RANDOM_LFO_SCALE = 0x3281900D, // C__Random_LFO_Scale
        C__RANDOM_LFO_SWITCH = 0x6150BC53, // C__Random_LFO_Switch
        D__SHIFT_MICROTONE = 0x9CBB1BF3, // D__Shift_Microtone
        D__SHIFT_TRANSPOSE = 0x4439D71, // D__Shift_Transpose
        E__FX_LEVEL = 0x890283C2, // E__Fx_Level
        E__HIPASS_FREQ = 0x12962685, // E__HiPass_Freq
        E__SHIFT_DELAY = 0x183CFEE5, // E__Shift_Delay
        E__SHIFT_WINDOW = 0x57FF40DB, // E__Shift_Window
        F__FX_DELAY = 0x69A91334, // F__FX_Delay
        F__FX_DELAY_FEEDBACK = 0x68D029F7, // F__FX_Delay_Feedback
        MIX__DRY_MIX = 0xD63693D0, // Mix__Dry_Mix
        MIX__DRY_VOL = 0x1FC3C02C, // Mix__Dry_Vol
        MIX__REVERB_LEVEL = 0x58653D84, // Mix__Reverb_Level
        MIX__REVERB_VOL = 0xE764F673, // Mix__Reverb_Vol
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_HZRlSvUa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_4uhoE5nR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_A0BbPB1B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_kKCq75NQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vBA0StjI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wwKkTi9h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_MqBJXvUs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3WsMvqbI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_xNHKKgnq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rvQdpH1U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_OuLoWFHs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_WMWWDyaA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_QfVinwBa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_2F5WBaIl_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_AhqF4Wug_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_etljesG5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ro92XAML_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QbMN59Nd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hBf44RvI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Kj8K5c3T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qiEpKkiy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_weBnraNR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1qadGV3Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_wVmX5sX6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_YZjX8hmp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_1kUuMKSo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uCC8BXOx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6surwDWd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_T1SptUns_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tMGjiHJf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_IhGYgyKi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_GV12EERs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_WLZ6ivVY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_g13LHGWe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UEJcIXgy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kdMsHZV2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kNA9s8fi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4WR2eiWu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_F2YRkMcN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_056XsCTN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8KS7Wink_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_t5C1hIjm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bvCXkPDC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PcfX3OOy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JZ2JbrL4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_v9fE2YCx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_qDXTgHkd_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_sms7WvGv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sGUXwLWr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Rz3iH9Br_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Coy7Zo0A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2lngMseC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2hE7623h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5OcgfgbN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_50PJgNfD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OHv70HmA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Rs96StZQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_82ySjEDd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SFgeJIel_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wZfiiSmw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_a2kANdA9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_d3XRxTu3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CSQmZmOs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_HycHHb1A_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_qYdLXGAJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_TmTT5sWa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cRandom_SLfCZAiH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_VcBitlUw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_YJAt0eez_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_MvgLe4KY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GW5WjBfU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_J84fwcle_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Mq3qYe8t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_19ByyUfF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fvdtHIfV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rL8zbQ6V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6Th86m5I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UhoDhSrX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_nkRsEUzG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iHCjHls0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_jiSqDD6u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zGjdzP6I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_4aK47lkA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_YsKyTDLn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_YdYzQAAo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Xe2UV846_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uMpPBlND_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WUyYgtXd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_qCtgLqnI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_z9Qxin4R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qiIoHy3h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_d7UEgPIY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jklaP2EB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zudyK2WP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UQItn2Oc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yy4xNQy9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7WH2YMjb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_fEDGYWso_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FSf7GyfT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_bug1UE9b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_l7yxOHqT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_vyvA5Ior_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_OFUiwHHd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_dp5qrxkc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fRy8PljG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_akJHtVNw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xGXeQUTd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_tacM82s0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6cruKUaW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dL3aVtht_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lciJZgSY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SHNQp9sW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vzZWG5jD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sMgCwlVH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Nn2wTKBg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LARdSwzD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_7RjnzB0n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0CRJFHIe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ifbmZvLR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5NxGnck5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_2uIw1SdJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_RhlFQfzT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_hwpN1FVr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oaFbyvir_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ypJOWfzw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rOaKjcLJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ApXcFR3K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_F6FNZPPZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BM4CBYlY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_H34mlmYC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_66jm88Vq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zARi1zXR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fofCltdf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uzcyQO7X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uVePE8K3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_cFqrwKXc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_z5JbvRpw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_hc5OLJqA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_QhGLWWzl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_anqj1Vt7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_qSVDzd9I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_bgxyfHM0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_e2qevqGT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_M67mBejy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mqhPETdP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_AlZ4ygIU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ik2LMBrV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nRTQJCxA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ghGqKZHQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eHpIOeQN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rl0KeNqv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_h3FEVPG9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_N6yiBXMF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MMTQnlWA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ak8IcJrK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_FvWDemum_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_VUxNpfSq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_njJpeKpX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_v09VMWXH_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_S6KZ2hBa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_lSqA0hGM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_W4MDAic7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zwdKa0BM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DqkvHvUM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZfgbtcIj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iaO03Def_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yScHEmsz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6hq4GrT2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_vPR35buV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Sofg59Fp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_t1TKGA17_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_zwjW9cwj_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_UaXnasND_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_0OecdYhI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wzM8ts7o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qxtN8ezK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_c5crcJv4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XLU0B9ao_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kqZEVRB6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_I8vWpI01_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cVxz00gk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_6VS0xOQ0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_sBZZmcod_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_E9ntm5BC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_JxmR3vTl_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_sGO7koJE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_8BLh59FN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mab7suAc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nv6Jah5E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tQPiyFvp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RZg7aBd8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pD7AO8bu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZgBwOMIc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uaqeeZFi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_HdDjT9LG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_FnBZAHs3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_NYQpO74l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_3nuhJvvI_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_WJN9XOPo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_yw0or66v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_I97Z3orq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ezid0K0P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3NTMSN6b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Q4EEhi51_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DefAZq96_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tbS01gdH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_YycXJJha_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_2bA5qlVC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2dSwGmAZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_T4FzDEdH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_LVg039Zy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_i9RXI1pV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_O5S569Cw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GfrukEvS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kf9hT6TT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DmADGokQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vS7puXO2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zMyhNeA4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cPljsI6z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_F04CV4Qc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_EmlW1xcy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_bXzBsHfY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_9VRQfEbG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_7l6qkrcS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_R5T4i2dA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OlUIuJgI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BcMTB5EY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rRgk1knQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_7B8o95Jo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_NNdei6j5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_9DCojqVw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_F9a0LR6O_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_vkmud98q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_JcPJtdX8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PlaIh7O4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ogRzMcHb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kSnPTWo6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_enDaajQ0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4UHxR4Qu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rtclQehK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_mB8eGBnS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XUaPpWxe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Nr3PlbS2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_U8HPWcfs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_s1DDvTxv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_K9JHoYFz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_CoX3wble_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IDUOirZ8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GYbROhud_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WUjBnVlx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_rqj4ow8I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tBZhjuva_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8Iij703G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XY8Rds3D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hUVy8K1b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Up1fincS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WEB8q0pA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DXohTEqV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_unzqdP4S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bThkrMD0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_46hLJSab_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_SjpArpzY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_BxilP7rm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_E1TEIKQ6_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_MfNMjCj5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_lwJzjTGw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_l62B7lzA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UyEwcV5E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_APJUyDu5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kbudFOiU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IbOfPV1B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_j32z2IOr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_1TJUXeJg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CNaEOk8Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_m0d4AX2x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_qvyAAzqM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_yfArtpXF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_peJTvmDJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_jJ7PExKm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_065IAkUf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aDU8T5lD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_36kgowr5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_N9Np2ibZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tblfE2u3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gZpDhNyN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_o6F3LKEg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PkQzA3Cu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fHCTgBcP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xaNhHOVv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MEI5mx6M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_S7wJPOf1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ApnEGHiw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_6DeMzKpQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_uDPesG5P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_a21bHihM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_QvdnUxfr_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_bFziMXl4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_UQoOOfNl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_drPuIEIr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_f3IuDBXw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OMNjjemh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YsZjuHKw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_E4L2Bfoz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_er7R39l2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_JSFERbKd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Zb5uYRQU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_lHUpcQfr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_z4fVGBv1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_0RW1uMai_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_iJLxFRuL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_ZIYbmxfc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Q7u3kEnX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7Wz2n0c8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kwBnG3Jg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_r62tlQEJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7cl3Pibs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HykXzUF6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_S6hdvgi7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QMTLpgeQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oIXB3rJS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fRxSN3pl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5VDv1s9d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iQ877nBD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4EC51hSK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_T3c4i16Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_xC6epfaf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_K38BUORK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_IjzRildJ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_cO0OuP71_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_OQfvzmDE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ExdNFEQp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jd0SrLcD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iEMWVPLl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3LXQ63Le_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ESV34sLo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SC5BHhWj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_O74lDE49_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zoJBKtPz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_mVZR73hl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_iR2BdYa7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_UCXc16UB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_G2G4Cf9u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_yxZVGmQe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SUvLmU5D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Vbm72ZUc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZgiIPrvp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Lb5VkZyU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZgK79SVm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_O1fsBRLJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_t8YgegOv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QJg3ewDy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BkLsuyd9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_j6GhnftQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GJ0TEmla_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Pmci1qtV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_R1L2GIwd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_3IEpWJyP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_2fzdfwpd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_EkJVcAly_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_gJbqui1i_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_33BAYXTZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_VrejEx9y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2A9scLC5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nOFQrdIZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_roejDsT9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_u4vtG0lr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_G2Ymjl5t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_plOLXp6K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_jLXcF4l0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dFHN4rGf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_0GsehIZX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_v9ywEZeh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_nDO3tAaP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_mhwQeGKe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_FWINubFZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_siJVlw0A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RQtrNqrB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ze1ELsCi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_A0B0lmjX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BthXbMCf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_W6UX3T96_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LroctHPY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yUvBILqm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_z1NHsz7m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_djhOWEdx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_V90zDXP3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eahemivZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hFDHXmBs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_pjoi4qCF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_WQIw8jhD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_FcXrjCxC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ov7Le00M_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_3VgOpELT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_TFIvtNDB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mWj9mzgx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lOT40ikm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_X8PRXeD2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_79Hfjl6S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_r0xtZCpA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vHnLdKp1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_UbpWbCAs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sIikIuuY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Mplf7lA4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_IdUrbUg3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_dK2gfBCv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_qHJVjmFc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_0Yp78Vy2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_omrsohxL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_I1WW3dla_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_w16dV3GY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_DXYxHAXy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xr0XRMaV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BLQZDrfR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_B7Nm3C9S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NUNnpmCm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZTKJHYrt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oc4qFEIp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QqZXy9NC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lrUaZY9v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_OmyZeat0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_BFqUkZdt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_vUzxNa7Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_WQqzeUI6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LiqpmzEC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_QnLoHGVd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OfsniVMN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TJppsHQF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XfOaQxjK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jcoTG8sg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8Lky5BRt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yUt8Ss5U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_VoWNtNBn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PERHAfq8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_trSBNttt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_f8HzUKSE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BJdxgGbq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CcANPeJL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DJYfSx45_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dnDJm33E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_o2K94SbH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_0Ql1vxro_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_N4rV1kKS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_qDh9pSDY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zJpwbBRX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Zwm6ogBM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JUI7gGTb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qZI8k37r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SoieggwP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pHd0juSs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QGvGkjGn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qV7pLj5S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JqIaNqpQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MFFYqgne_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_izVCusjt_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_zMPQ7yMT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GI5SB8Fq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VVFJPxFF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Q8PayyL5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_jUq8fEyy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EvZjk8eg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yIFpWtyG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LoMWZMdZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qnmONYi4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_YhdzLPtL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_aZFYGOL4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_SGOeZOhi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_0pvjv2yC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_rZqOfbUa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WTUXBcnl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CTlE07af_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Tn0lytK1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_xk3laogU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_NWcGrMHG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_82oilqLU_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_wSRmbHbU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_NpNlKGon_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hyf4gS9x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MDdkm0DN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7XEOSRa6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2EGNMIPt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_p6OGvSx0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bWUe2Yl2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_IUQqaRy9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8FQTrOc6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_qCm3BC35_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5prN7IYv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_PJiOm9TI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_yfzXyLrh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_zC2hurIb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Jswl3Cab_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_T6wSPXEo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Qs0ZNzKE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_HMqEUNnx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Sxf7h75i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tLEhTGpY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zQUJvpRJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yK6Z6Xdn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_B4FP2ni1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kFLCYIoO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LkFDHgTm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0I8KqCCq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_NDcFGJ2y_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_fraV82Gm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_gAw5Efmi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_vak9SsEn_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_wG4qY0zO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_IeF8WKaC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KnY69inE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_WA3kYTMG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_fxaE9vpq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_foJcGGTd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_A8ICpHcf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_SJ07mW3H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_58ZW9mbc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_grG86slH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_59R8Ii3u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_8oFODdyr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_0ETmwLSC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_lUXrF3Oi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OAF7EUKO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_suL30wVz_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_9hWjDD2b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_uLP4MPv6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zgVuiF7H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_kGjgWGfy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BGzAxItw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_no9P8tSl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xPOTMvFf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Wf18NXmU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jcNXNV1s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_RDYFTCpJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_zKP2urHc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_zTdbgkHK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_7FyueW7f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_1cfsMPRp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BNYl8eMr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FeiBB6L6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_loB8XIn6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Bj2jLz2v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0yTnxXW4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zWC3ScTb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YaEqDzcr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0LRjEbnW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kwhJGtmg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fGxHXdjz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_E1hKMInb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IuIrIB46_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6qCVfqJn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QNirziww_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PRiAvzbv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kmAwqT7F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_q2s0Ek5t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mEczP16U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0auKD71l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zwON1LRY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PHX7YZ7d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UQ5zoNVs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_S4XgtMpH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3VOJpJNd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xfcLJoiD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kfMbnhIg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nxXhdqQc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TsUsgWBZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0jB2bvVX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ikaC1rdQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_F7wn6FAQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0D1evoLq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gF2ANyGN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CPzGaWXd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_U1cmsGJK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iu4HlLue_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mWhY59ST_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FucmKUpZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QGMySUek_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AN7R2O3h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GPohGfZH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fGbKkObY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EmgT8dZD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kzrR0426_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GUDfZ3pn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CGPbYBrR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_PyyMWJsu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_7EZsLRIm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_iqoTcYmZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_XCQD18R8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_GATK0CxN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_eY41Qemk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ODmFsjRj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_btGfvAme_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_22QwyOO1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_iffMoq8w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_4F2uLaUK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_JhROtCwj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_2bCaFxqj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_XYQesTDN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_I2QqTtZI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_S0sG2IoD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_sD4P3ECJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ZreJBCML_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_EruxOk1F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_tWGDq7C6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_MMEkQhWo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_m3uXQ87J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_fqCkZ6ZE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_mfZmkl1P_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalPhasor sPhasor_Edfdcaxi;
  SignalLine sLine_1cpZyiXb;
  SignalLine sLine_E6P7DZ0d;
  SignalTabhead sTabhead_8RgebfgV;
  SignalTabread sTabread_A0E5QkPS;
  SignalTabread sTabread_8yEFsUds;
  SignalTabhead sTabhead_lV4ybl91;
  SignalTabread sTabread_asi8Lk76;
  SignalTabread sTabread_yZ1W6nNx;
  SignalTabwrite sTabwrite_p4H0tNBb;
  SignalRPole sRPole_RlchLP8I;
  SignalDel1 sDel1_ELV94o3k;
  SignalTabread sTabread_zC2hurIb;
  SignalTabwrite sTabwrite_IcRmV8Ph;
  SignalTabread sTabread_YdYzQAAo;
  SignalRPole sRPole_msRyLgWs;
  SignalLine sLine_h4wmVr7S;
  SignalLine sLine_dun5Gj9V;
  SignalTabread sTabread_CoX3wble;
  SignalTabread sTabread_jJ7PExKm;
  SignalTabread sTabread_ZIYbmxfc;
  SignalTabread sTabread_yxZVGmQe;
  SignalTabread sTabread_0Yp78Vy2;
  SignalTabread sTabread_FWINubFZ;
  SignalTabwrite sTabwrite_EyVrZebd;
  SignalTabwrite sTabwrite_uqn6ZC3h;
  SignalTabwrite sTabwrite_qCypALpj;
  SignalTabwrite sTabwrite_dlW0w2uZ;
  SignalTabwrite sTabwrite_dKmFcwEG;
  SignalTabwrite sTabwrite_C1x6jfsH;
  SignalTabread sTabread_dp5qrxkc;
  SignalRPole sRPole_LVDZeQFQ;
  SignalTabread sTabread_hwpN1FVr;
  SignalRPole sRPole_Piz6KqHV;
  SignalTabread sTabread_bgxyfHM0;
  SignalRPole sRPole_xBjYFzNr;
  SignalTabwrite sTabwrite_72K7vOpf;
  SignalTabwrite sTabwrite_mLOgGEWK;
  SignalTabwrite sTabwrite_7QhySYme;
  SignalTabwrite sTabwrite_voKIXw9m;
  SignalLine sLine_hny6jqOl;
  ControlVar cVar_HZRlSvUa;
  ControlVar cVar_4uhoE5nR;
  ControlPack cPack_A0BbPB1B;
  ControlBinop cBinop_vBA0StjI;
  ControlVar cVar_wwKkTi9h;
  ControlPack cPack_MqBJXvUs;
  ControlVar cVar_3WsMvqbI;
  ControlVar cVar_xNHKKgnq;
  ControlDelay cDelay_WMWWDyaA;
  ControlDelay cDelay_QfVinwBa;
  ControlBinop cBinop_AhqF4Wug;
  HvTable hTable_etljesG5;
  ControlBinop cBinop_QbMN59Nd;
  ControlVar cVar_YZjX8hmp;
  ControlBinop cBinop_uCC8BXOx;
  ControlBinop cBinop_T1SptUns;
  SignalVarf sVarf_AtsFugVf;
  SignalVarf sVarf_5QEHi7QD;
  SignalVarf sVarf_d3h77QEQ;
  ControlVar cVar_GV12EERs;
  ControlBinop cBinop_g13LHGWe;
  ControlBinop cBinop_kdMsHZV2;
  SignalVarf sVarf_7WsEA8Ie;
  SignalVarf sVarf_QopkJA3T;
  SignalVarf sVarf_2Wh1pN0p;
  ControlBinop cBinop_kNA9s8fi;
  ControlBinop cBinop_4WR2eiWu;
  ControlBinop cBinop_8KS7Wink;
  ControlBinop cBinop_t5C1hIjm;
  ControlBinop cBinop_bvCXkPDC;
  ControlBinop cBinop_PcfX3OOy;
  ControlBinop cBinop_JZ2JbrL4;
  ControlBinop cBinop_Coy7Zo0A;
  ControlBinop cBinop_2lngMseC;
  SignalVarf sVarf_AYADOSxP;
  ControlVar cVar_2hE7623h;
  ControlBinop cBinop_OHv70HmA;
  ControlBinop cBinop_Rs96StZQ;
  ControlBinop cBinop_SFgeJIel;
  ControlBinop cBinop_wZfiiSmw;
  ControlBinop cBinop_a2kANdA9;
  ControlBinop cBinop_d3XRxTu3;
  ControlBinop cBinop_CSQmZmOs;
  SignalVarf sVarf_0RK74LDG;
  ControlBinop cBinop_qYdLXGAJ;
  ControlRandom cRandom_SLfCZAiH;
  ControlSlice cSlice_VcBitlUw;
  ControlDelay cDelay_MvgLe4KY;
  ControlVar cVar_19ByyUfF;
  ControlBinop cBinop_rL8zbQ6V;
  ControlBinop cBinop_6Th86m5I;
  ControlBinop cBinop_UhoDhSrX;
  ControlTabhead cTabhead_nkRsEUzG;
  ControlVar cVar_zGjdzP6I;
  ControlDelay cDelay_4aK47lkA;
  ControlDelay cDelay_YsKyTDLn;
  ControlBinop cBinop_Xe2UV846;
  ControlBinop cBinop_uMpPBlND;
  ControlBinop cBinop_WUyYgtXd;
  ControlBinop cBinop_jklaP2EB;
  ControlBinop cBinop_UQItn2Oc;
  ControlBinop cBinop_yy4xNQy9;
  ControlTabhead cTabhead_fEDGYWso;
  ControlVar cVar_l7yxOHqT;
  ControlDelay cDelay_vyvA5Ior;
  ControlDelay cDelay_OFUiwHHd;
  ControlBinop cBinop_fRy8PljG;
  ControlBinop cBinop_akJHtVNw;
  ControlBinop cBinop_xGXeQUTd;
  ControlBinop cBinop_SHNQp9sW;
  ControlBinop cBinop_sMgCwlVH;
  ControlBinop cBinop_Nn2wTKBg;
  ControlTabhead cTabhead_7RjnzB0n;
  ControlVar cVar_5NxGnck5;
  ControlDelay cDelay_2uIw1SdJ;
  ControlDelay cDelay_RhlFQfzT;
  ControlBinop cBinop_oaFbyvir;
  ControlBinop cBinop_ypJOWfzw;
  ControlBinop cBinop_rOaKjcLJ;
  ControlBinop cBinop_66jm88Vq;
  ControlBinop cBinop_fofCltdf;
  ControlBinop cBinop_uzcyQO7X;
  ControlTabhead cTabhead_cFqrwKXc;
  ControlVar cVar_QhGLWWzl;
  ControlDelay cDelay_anqj1Vt7;
  ControlDelay cDelay_qSVDzd9I;
  ControlBinop cBinop_e2qevqGT;
  ControlBinop cBinop_M67mBejy;
  ControlBinop cBinop_mqhPETdP;
  ControlBinop cBinop_eHpIOeQN;
  ControlBinop cBinop_h3FEVPG9;
  ControlBinop cBinop_N6yiBXMF;
  ControlDelay cDelay_VUxNpfSq;
  ControlDelay cDelay_njJpeKpX;
  ControlBinop cBinop_S6KZ2hBa;
  HvTable hTable_lSqA0hGM;
  ControlBinop cBinop_zwdKa0BM;
  ControlDelay cDelay_Sofg59Fp;
  ControlDelay cDelay_t1TKGA17;
  ControlBinop cBinop_UaXnasND;
  HvTable hTable_0OecdYhI;
  ControlBinop cBinop_qxtN8ezK;
  ControlDelay cDelay_sBZZmcod;
  ControlDelay cDelay_E9ntm5BC;
  ControlBinop cBinop_sGO7koJE;
  HvTable hTable_8BLh59FN;
  ControlBinop cBinop_nv6Jah5E;
  ControlDelay cDelay_FnBZAHs3;
  ControlDelay cDelay_NYQpO74l;
  ControlBinop cBinop_WJN9XOPo;
  HvTable hTable_yw0or66v;
  ControlBinop cBinop_ezid0K0P;
  ControlPack cPack_YycXJJha;
  ControlPack cPack_2bA5qlVC;
  ControlBinop cBinop_2dSwGmAZ;
  ControlBinop cBinop_T4FzDEdH;
  ControlVar cVar_LVg039Zy;
  ControlBinop cBinop_GfrukEvS;
  ControlBinop cBinop_kf9hT6TT;
  SignalVarf sVarf_jRVRQoZd;
  ControlBinop cBinop_vS7puXO2;
  ControlBinop cBinop_zMyhNeA4;
  ControlBinop cBinop_cPljsI6z;
  SignalVarf sVarf_zhSdwg0C;
  ControlVar cVar_F04CV4Qc;
  ControlVar cVar_EmlW1xcy;
  ControlVar cVar_bXzBsHfY;
  ControlVar cVar_9VRQfEbG;
  ControlIf cIf_7l6qkrcS;
  ControlBinop cBinop_R5T4i2dA;
  ControlBinop cBinop_OlUIuJgI;
  ControlBinop cBinop_BcMTB5EY;
  ControlDelay cDelay_NNdei6j5;
  ControlDelay cDelay_9DCojqVw;
  ControlBinop cBinop_vkmud98q;
  HvTable hTable_JcPJtdX8;
  ControlBinop cBinop_ogRzMcHb;
  ControlTabhead cTabhead_mB8eGBnS;
  ControlVar cVar_U8HPWcfs;
  ControlDelay cDelay_s1DDvTxv;
  ControlDelay cDelay_K9JHoYFz;
  ControlBinop cBinop_IDUOirZ8;
  ControlBinop cBinop_GYbROhud;
  ControlBinop cBinop_WUjBnVlx;
  ControlBinop cBinop_hUVy8K1b;
  ControlBinop cBinop_WEB8q0pA;
  ControlBinop cBinop_DXohTEqV;
  ControlDelay cDelay_SjpArpzY;
  ControlDelay cDelay_BxilP7rm;
  ControlBinop cBinop_MfNMjCj5;
  HvTable hTable_lwJzjTGw;
  ControlBinop cBinop_UyEwcV5E;
  ControlTabhead cTabhead_1TJUXeJg;
  ControlVar cVar_qvyAAzqM;
  ControlDelay cDelay_yfArtpXF;
  ControlDelay cDelay_peJTvmDJ;
  ControlBinop cBinop_065IAkUf;
  ControlBinop cBinop_aDU8T5lD;
  ControlBinop cBinop_36kgowr5;
  ControlBinop cBinop_PkQzA3Cu;
  ControlBinop cBinop_xaNhHOVv;
  ControlBinop cBinop_MEI5mx6M;
  ControlDelay cDelay_uDPesG5P;
  ControlDelay cDelay_a21bHihM;
  ControlBinop cBinop_bFziMXl4;
  HvTable hTable_UQoOOfNl;
  ControlBinop cBinop_f3IuDBXw;
  ControlTabhead cTabhead_JSFERbKd;
  ControlVar cVar_z4fVGBv1;
  ControlDelay cDelay_0RW1uMai;
  ControlDelay cDelay_iJLxFRuL;
  ControlBinop cBinop_Q7u3kEnX;
  ControlBinop cBinop_7Wz2n0c8;
  ControlBinop cBinop_kwBnG3Jg;
  ControlBinop cBinop_QMTLpgeQ;
  ControlBinop cBinop_fRxSN3pl;
  ControlBinop cBinop_5VDv1s9d;
  ControlDelay cDelay_xC6epfaf;
  ControlDelay cDelay_K38BUORK;
  ControlBinop cBinop_cO0OuP71;
  HvTable hTable_OQfvzmDE;
  ControlBinop cBinop_jd0SrLcD;
  ControlTabhead cTabhead_O74lDE49;
  ControlVar cVar_iR2BdYa7;
  ControlDelay cDelay_UCXc16UB;
  ControlDelay cDelay_G2G4Cf9u;
  ControlBinop cBinop_SUvLmU5D;
  ControlBinop cBinop_Vbm72ZUc;
  ControlBinop cBinop_ZgiIPrvp;
  ControlBinop cBinop_QJg3ewDy;
  ControlBinop cBinop_j6GhnftQ;
  ControlBinop cBinop_GJ0TEmla;
  ControlDelay cDelay_2fzdfwpd;
  ControlDelay cDelay_EkJVcAly;
  ControlBinop cBinop_33BAYXTZ;
  HvTable hTable_VrejEx9y;
  ControlBinop cBinop_nOFQrdIZ;
  ControlTabhead cTabhead_jLXcF4l0;
  ControlVar cVar_v9ywEZeh;
  ControlDelay cDelay_nDO3tAaP;
  ControlDelay cDelay_mhwQeGKe;
  ControlBinop cBinop_siJVlw0A;
  ControlBinop cBinop_RQtrNqrB;
  ControlBinop cBinop_ze1ELsCi;
  ControlBinop cBinop_yUvBILqm;
  ControlBinop cBinop_djhOWEdx;
  ControlBinop cBinop_V90zDXP3;
  ControlDelay cDelay_WQIw8jhD;
  ControlDelay cDelay_FcXrjCxC;
  ControlBinop cBinop_3VgOpELT;
  HvTable hTable_TFIvtNDB;
  ControlBinop cBinop_lOT40ikm;
  ControlTabhead cTabhead_UbpWbCAs;
  ControlVar cVar_IdUrbUg3;
  ControlDelay cDelay_dK2gfBCv;
  ControlDelay cDelay_qHJVjmFc;
  ControlBinop cBinop_omrsohxL;
  ControlBinop cBinop_I1WW3dla;
  ControlBinop cBinop_w16dV3GY;
  ControlBinop cBinop_NUNnpmCm;
  ControlBinop cBinop_oc4qFEIp;
  ControlBinop cBinop_QqZXy9NC;
  ControlVar cVar_OmyZeat0;
  ControlVar cVar_BFqUkZdt;
  ControlPack cPack_vUzxNa7Q;
  ControlVar cVar_WQqzeUI6;
  ControlBinop cBinop_OfsniVMN;
  ControlBinop cBinop_TJppsHQF;
  SignalVarf sVarf_FqY9qwzt;
  ControlBinop cBinop_jcoTG8sg;
  ControlBinop cBinop_8Lky5BRt;
  ControlBinop cBinop_yUt8Ss5U;
  SignalVarf sVarf_rpVvtY5w;
  ControlVar cVar_VoWNtNBn;
  ControlBinop cBinop_f8HzUKSE;
  ControlBinop cBinop_BJdxgGbq;
  SignalVarf sVarf_d9eekS1V;
  ControlBinop cBinop_DJYfSx45;
  ControlBinop cBinop_dnDJm33E;
  ControlBinop cBinop_o2K94SbH;
  SignalVarf sVarf_QLavkFjC;
  ControlVar cVar_0Ql1vxro;
  ControlBinop cBinop_zJpwbBRX;
  ControlBinop cBinop_Zwm6ogBM;
  SignalVarf sVarf_cSCNr5LN;
  ControlBinop cBinop_qZI8k37r;
  ControlBinop cBinop_SoieggwP;
  ControlBinop cBinop_pHd0juSs;
  SignalVarf sVarf_ARZ35i2H;
  ControlBinop cBinop_QGvGkjGn;
  ControlBinop cBinop_JqIaNqpQ;
  ControlBinop cBinop_MFFYqgne;
  ControlDelay cDelay_zMPQ7yMT;
  ControlVar cVar_jUq8fEyy;
  ControlBinop cBinop_yIFpWtyG;
  ControlBinop cBinop_LoMWZMdZ;
  ControlBinop cBinop_qnmONYi4;
  ControlVar cVar_YhdzLPtL;
  ControlVar cVar_aZFYGOL4;
  ControlIf cIf_rZqOfbUa;
  ControlBinop cBinop_WTUXBcnl;
  ControlDelay cDelay_xk3laogU;
  ControlDelay cDelay_NWcGrMHG;
  ControlBinop cBinop_wSRmbHbU;
  HvTable hTable_NpNlKGon;
  ControlBinop cBinop_MDdkm0DN;
  ControlTabhead cTabhead_IUQqaRy9;
  ControlVar cVar_5prN7IYv;
  ControlDelay cDelay_PJiOm9TI;
  ControlDelay cDelay_yfzXyLrh;
  ControlBinop cBinop_Jswl3Cab;
  ControlBinop cBinop_T6wSPXEo;
  ControlBinop cBinop_Qs0ZNzKE;
  ControlBinop cBinop_yK6Z6Xdn;
  ControlBinop cBinop_kFLCYIoO;
  ControlBinop cBinop_LkFDHgTm;
  ControlVar cVar_gAw5Efmi;
  ControlVar cVar_IeF8WKaC;
  ControlVar cVar_KnY69inE;
  ControlVar cVar_WA3kYTMG;
  ControlVar cVar_fxaE9vpq;
  ControlVar cVar_foJcGGTd;
  ControlIf cIf_58ZW9mbc;
  ControlBinop cBinop_grG86slH;
  ControlVar cVar_59R8Ii3u;
  ControlIf cIf_lUXrF3Oi;
  ControlBinop cBinop_OAF7EUKO;
  ControlSlice cSlice_9hWjDD2b;
  ControlSlice cSlice_uLP4MPv6;
  ControlVar cVar_zgVuiF7H;
  ControlIf cIf_kGjgWGfy;
  ControlBinop cBinop_xPOTMvFf;
  ControlIf cIf_RDYFTCpJ;
  ControlIf cIf_zKP2urHc;
  ControlIf cIf_zTdbgkHK;
  ControlIf cIf_7FyueW7f;
  ControlIf cIf_1cfsMPRp;
  SignalVarf sVarf_oIfxBiP6;
  ControlBinop cBinop_0yTnxXW4;
  ControlBinop cBinop_zWC3ScTb;
  ControlBinop cBinop_0LRjEbnW;
  ControlBinop cBinop_kwhJGtmg;
  SignalVarf sVarf_XEB4jDt2;
  ControlBinop cBinop_E1hKMInb;
  ControlBinop cBinop_IuIrIB46;
  SignalVarf sVarf_jZbszGbo;
  SignalVarf sVarf_2OPSV9yg;
  ControlBinop cBinop_q2s0Ek5t;
  ControlBinop cBinop_mEczP16U;
  ControlBinop cBinop_0auKD71l;
  ControlBinop cBinop_zwON1LRY;
  ControlBinop cBinop_UQ5zoNVs;
  ControlBinop cBinop_S4XgtMpH;
  ControlBinop cBinop_3VOJpJNd;
  ControlBinop cBinop_xfcLJoiD;
  ControlBinop cBinop_nxXhdqQc;
  ControlBinop cBinop_TsUsgWBZ;
  ControlBinop cBinop_0jB2bvVX;
  ControlBinop cBinop_AN7R2O3h;
  ControlBinop cBinop_GPohGfZH;
};

#endif // _HEAVY_CONTEXT_CHAFFVERB_HPP_
