/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_ChaffVerb.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_ChaffVerb *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_ChaffVerb_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_ChaffVerb));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_ChaffVerb(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_ChaffVerb_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_ChaffVerb));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_ChaffVerb(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_ChaffVerb_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_ChaffVerb();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_ChaffVerb::Heavy_ChaffVerb(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sPhasor_k_init(&sPhasor_Edfdcaxi, 0.0f, sampleRate);
  numBytes += sLine_init(&sLine_1cpZyiXb);
  numBytes += sLine_init(&sLine_E6P7DZ0d);
  numBytes += sTabhead_init(&sTabhead_8RgebfgV, &hTable_etljesG5);
  numBytes += sTabread_init(&sTabread_A0E5QkPS, &hTable_etljesG5, false);
  numBytes += sTabread_init(&sTabread_8yEFsUds, &hTable_etljesG5, false);
  numBytes += sTabhead_init(&sTabhead_lV4ybl91, &hTable_etljesG5);
  numBytes += sTabread_init(&sTabread_asi8Lk76, &hTable_etljesG5, false);
  numBytes += sTabread_init(&sTabread_yZ1W6nNx, &hTable_etljesG5, false);
  numBytes += sTabwrite_init(&sTabwrite_p4H0tNBb, &hTable_etljesG5);
  numBytes += sRPole_init(&sRPole_RlchLP8I);
  numBytes += sDel1_init(&sDel1_ELV94o3k);
  numBytes += sTabread_init(&sTabread_zC2hurIb, &hTable_NpNlKGon, true);
  numBytes += sTabwrite_init(&sTabwrite_IcRmV8Ph, &hTable_NpNlKGon);
  numBytes += sTabread_init(&sTabread_YdYzQAAo, &hTable_lSqA0hGM, true);
  numBytes += sRPole_init(&sRPole_msRyLgWs);
  numBytes += sLine_init(&sLine_h4wmVr7S);
  numBytes += sLine_init(&sLine_dun5Gj9V);
  numBytes += sTabread_init(&sTabread_CoX3wble, &hTable_JcPJtdX8, true);
  numBytes += sTabread_init(&sTabread_jJ7PExKm, &hTable_lwJzjTGw, true);
  numBytes += sTabread_init(&sTabread_ZIYbmxfc, &hTable_UQoOOfNl, true);
  numBytes += sTabread_init(&sTabread_yxZVGmQe, &hTable_OQfvzmDE, true);
  numBytes += sTabread_init(&sTabread_0Yp78Vy2, &hTable_TFIvtNDB, true);
  numBytes += sTabread_init(&sTabread_FWINubFZ, &hTable_VrejEx9y, true);
  numBytes += sTabwrite_init(&sTabwrite_EyVrZebd, &hTable_JcPJtdX8);
  numBytes += sTabwrite_init(&sTabwrite_uqn6ZC3h, &hTable_lwJzjTGw);
  numBytes += sTabwrite_init(&sTabwrite_qCypALpj, &hTable_UQoOOfNl);
  numBytes += sTabwrite_init(&sTabwrite_dlW0w2uZ, &hTable_OQfvzmDE);
  numBytes += sTabwrite_init(&sTabwrite_dKmFcwEG, &hTable_VrejEx9y);
  numBytes += sTabwrite_init(&sTabwrite_C1x6jfsH, &hTable_TFIvtNDB);
  numBytes += sTabread_init(&sTabread_dp5qrxkc, &hTable_0OecdYhI, true);
  numBytes += sRPole_init(&sRPole_LVDZeQFQ);
  numBytes += sTabread_init(&sTabread_hwpN1FVr, &hTable_8BLh59FN, true);
  numBytes += sRPole_init(&sRPole_Piz6KqHV);
  numBytes += sTabread_init(&sTabread_bgxyfHM0, &hTable_yw0or66v, true);
  numBytes += sRPole_init(&sRPole_xBjYFzNr);
  numBytes += sTabwrite_init(&sTabwrite_72K7vOpf, &hTable_lSqA0hGM);
  numBytes += sTabwrite_init(&sTabwrite_mLOgGEWK, &hTable_0OecdYhI);
  numBytes += sTabwrite_init(&sTabwrite_7QhySYme, &hTable_8BLh59FN);
  numBytes += sTabwrite_init(&sTabwrite_voKIXw9m, &hTable_yw0or66v);
  numBytes += sLine_init(&sLine_hny6jqOl);
  numBytes += cVar_init_f(&cVar_HZRlSvUa, 0.0f);
  numBytes += cVar_init_f(&cVar_4uhoE5nR, 0.0f);
  numBytes += cPack_init(&cPack_A0BbPB1B, 2, 0.0f, 200.0f);
  numBytes += cVar_init_f(&cVar_wwKkTi9h, 0.0f);
  numBytes += cPack_init(&cPack_MqBJXvUs, 2, 0.0f, 200.0f);
  numBytes += cVar_init_f(&cVar_3WsMvqbI, 0.0f);
  numBytes += cVar_init_f(&cVar_xNHKKgnq, 0.0f);
  numBytes += cDelay_init(this, &cDelay_WMWWDyaA, 0.0f);
  numBytes += cDelay_init(this, &cDelay_QfVinwBa, 0.0f);
  numBytes += hTable_init(&hTable_etljesG5, 256);
  numBytes += cVar_init_s(&cVar_YZjX8hmp, "del-1002-shifter");
  numBytes += sVarf_init(&sVarf_AtsFugVf, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5QEHi7QD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_d3h77QEQ, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_GV12EERs, "del-1002-shifter");
  numBytes += sVarf_init(&sVarf_7WsEA8Ie, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QopkJA3T, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2Wh1pN0p, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_kNA9s8fi, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_AYADOSxP, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_2hE7623h, 0.0f);
  numBytes += cBinop_init(&cBinop_CSQmZmOs, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_0RK74LDG, 0.0f, 0.0f, false);
  numBytes += cRandom_init(&cRandom_SLfCZAiH, -1167652867);
  numBytes += cSlice_init(&cSlice_VcBitlUw, 1, 1);
  numBytes += cDelay_init(this, &cDelay_MvgLe4KY, 0.0f);
  numBytes += cVar_init_f(&cVar_19ByyUfF, 5.0f);
  numBytes += cBinop_init(&cBinop_UhoDhSrX, 0.0f); // __mul
  numBytes += cTabhead_init(&cTabhead_nkRsEUzG, &hTable_lSqA0hGM);
  numBytes += cVar_init_s(&cVar_zGjdzP6I, "del-1052-del1");
  numBytes += cDelay_init(this, &cDelay_4aK47lkA, 58.6435f);
  numBytes += cDelay_init(this, &cDelay_YsKyTDLn, 0.0f);
  numBytes += cBinop_init(&cBinop_Xe2UV846, 58.6435f); // __mul
  numBytes += cBinop_init(&cBinop_WUyYgtXd, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_jklaP2EB, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_yy4xNQy9, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_fEDGYWso, &hTable_0OecdYhI);
  numBytes += cVar_init_s(&cVar_l7yxOHqT, "del-1052-del2");
  numBytes += cDelay_init(this, &cDelay_vyvA5Ior, 69.4325f);
  numBytes += cDelay_init(this, &cDelay_OFUiwHHd, 0.0f);
  numBytes += cBinop_init(&cBinop_fRy8PljG, 69.4325f); // __mul
  numBytes += cBinop_init(&cBinop_xGXeQUTd, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_SHNQp9sW, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_Nn2wTKBg, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_7RjnzB0n, &hTable_8BLh59FN);
  numBytes += cVar_init_s(&cVar_5NxGnck5, "del-1052-del3");
  numBytes += cDelay_init(this, &cDelay_2uIw1SdJ, 74.5234f);
  numBytes += cDelay_init(this, &cDelay_RhlFQfzT, 0.0f);
  numBytes += cBinop_init(&cBinop_oaFbyvir, 74.5234f); // __mul
  numBytes += cBinop_init(&cBinop_rOaKjcLJ, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_66jm88Vq, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_uzcyQO7X, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_cFqrwKXc, &hTable_yw0or66v);
  numBytes += cVar_init_s(&cVar_QhGLWWzl, "del-1052-del4");
  numBytes += cDelay_init(this, &cDelay_anqj1Vt7, 86.1244f);
  numBytes += cDelay_init(this, &cDelay_qSVDzd9I, 0.0f);
  numBytes += cBinop_init(&cBinop_e2qevqGT, 86.1244f); // __mul
  numBytes += cBinop_init(&cBinop_mqhPETdP, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_eHpIOeQN, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_N6yiBXMF, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_VUxNpfSq, 0.0f);
  numBytes += cDelay_init(this, &cDelay_njJpeKpX, 0.0f);
  numBytes += hTable_init(&hTable_lSqA0hGM, 256);
  numBytes += cDelay_init(this, &cDelay_Sofg59Fp, 0.0f);
  numBytes += cDelay_init(this, &cDelay_t1TKGA17, 0.0f);
  numBytes += hTable_init(&hTable_0OecdYhI, 256);
  numBytes += cDelay_init(this, &cDelay_sBZZmcod, 0.0f);
  numBytes += cDelay_init(this, &cDelay_E9ntm5BC, 0.0f);
  numBytes += hTable_init(&hTable_8BLh59FN, 256);
  numBytes += cDelay_init(this, &cDelay_FnBZAHs3, 0.0f);
  numBytes += cDelay_init(this, &cDelay_NYQpO74l, 0.0f);
  numBytes += hTable_init(&hTable_yw0or66v, 256);
  numBytes += cPack_init(&cPack_YycXJJha, 2, 0.0f, 30.0f);
  numBytes += cPack_init(&cPack_2bA5qlVC, 2, 0.0f, 50.0f);
  numBytes += cVar_init_f(&cVar_LVg039Zy, 22050.0f);
  numBytes += cBinop_init(&cBinop_GfrukEvS, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_jRVRQoZd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_zhSdwg0C, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_F04CV4Qc, 0.0f);
  numBytes += cVar_init_f(&cVar_EmlW1xcy, 0.0f);
  numBytes += cVar_init_f(&cVar_bXzBsHfY, 0.0f);
  numBytes += cVar_init_f(&cVar_9VRQfEbG, 0.0f);
  numBytes += cIf_init(&cIf_7l6qkrcS, false);
  numBytes += cDelay_init(this, &cDelay_NNdei6j5, 0.0f);
  numBytes += cDelay_init(this, &cDelay_9DCojqVw, 0.0f);
  numBytes += hTable_init(&hTable_JcPJtdX8, 256);
  numBytes += cTabhead_init(&cTabhead_mB8eGBnS, &hTable_JcPJtdX8);
  numBytes += cVar_init_s(&cVar_U8HPWcfs, "del-1052-ref1");
  numBytes += cDelay_init(this, &cDelay_s1DDvTxv, 43.5337f);
  numBytes += cDelay_init(this, &cDelay_K9JHoYFz, 0.0f);
  numBytes += cBinop_init(&cBinop_IDUOirZ8, 43.5337f); // __mul
  numBytes += cBinop_init(&cBinop_WUjBnVlx, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_hUVy8K1b, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_DXohTEqV, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_SjpArpzY, 0.0f);
  numBytes += cDelay_init(this, &cDelay_BxilP7rm, 0.0f);
  numBytes += hTable_init(&hTable_lwJzjTGw, 256);
  numBytes += cTabhead_init(&cTabhead_1TJUXeJg, &hTable_lwJzjTGw);
  numBytes += cVar_init_s(&cVar_qvyAAzqM, "del-1052-ref2");
  numBytes += cDelay_init(this, &cDelay_yfArtpXF, 25.796f);
  numBytes += cDelay_init(this, &cDelay_peJTvmDJ, 0.0f);
  numBytes += cBinop_init(&cBinop_065IAkUf, 25.796f); // __mul
  numBytes += cBinop_init(&cBinop_36kgowr5, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_PkQzA3Cu, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_MEI5mx6M, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_uDPesG5P, 0.0f);
  numBytes += cDelay_init(this, &cDelay_a21bHihM, 0.0f);
  numBytes += hTable_init(&hTable_UQoOOfNl, 256);
  numBytes += cTabhead_init(&cTabhead_JSFERbKd, &hTable_UQoOOfNl);
  numBytes += cVar_init_s(&cVar_z4fVGBv1, "del-1052-ref3");
  numBytes += cDelay_init(this, &cDelay_0RW1uMai, 19.392f);
  numBytes += cDelay_init(this, &cDelay_iJLxFRuL, 0.0f);
  numBytes += cBinop_init(&cBinop_Q7u3kEnX, 19.392f); // __mul
  numBytes += cBinop_init(&cBinop_kwBnG3Jg, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_QMTLpgeQ, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_5VDv1s9d, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_xC6epfaf, 0.0f);
  numBytes += cDelay_init(this, &cDelay_K38BUORK, 0.0f);
  numBytes += hTable_init(&hTable_OQfvzmDE, 256);
  numBytes += cTabhead_init(&cTabhead_O74lDE49, &hTable_OQfvzmDE);
  numBytes += cVar_init_s(&cVar_iR2BdYa7, "del-1052-ref4");
  numBytes += cDelay_init(this, &cDelay_UCXc16UB, 16.364f);
  numBytes += cDelay_init(this, &cDelay_G2G4Cf9u, 0.0f);
  numBytes += cBinop_init(&cBinop_SUvLmU5D, 16.364f); // __mul
  numBytes += cBinop_init(&cBinop_ZgiIPrvp, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_QJg3ewDy, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_GJ0TEmla, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_2fzdfwpd, 0.0f);
  numBytes += cDelay_init(this, &cDelay_EkJVcAly, 0.0f);
  numBytes += hTable_init(&hTable_VrejEx9y, 256);
  numBytes += cTabhead_init(&cTabhead_jLXcF4l0, &hTable_VrejEx9y);
  numBytes += cVar_init_s(&cVar_v9ywEZeh, "del-1052-ref6");
  numBytes += cDelay_init(this, &cDelay_nDO3tAaP, 4.2546f);
  numBytes += cDelay_init(this, &cDelay_mhwQeGKe, 0.0f);
  numBytes += cBinop_init(&cBinop_siJVlw0A, 4.2546f); // __mul
  numBytes += cBinop_init(&cBinop_ze1ELsCi, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_yUvBILqm, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_V90zDXP3, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_WQIw8jhD, 0.0f);
  numBytes += cDelay_init(this, &cDelay_FcXrjCxC, 0.0f);
  numBytes += hTable_init(&hTable_TFIvtNDB, 256);
  numBytes += cTabhead_init(&cTabhead_UbpWbCAs, &hTable_TFIvtNDB);
  numBytes += cVar_init_s(&cVar_IdUrbUg3, "del-1052-ref5");
  numBytes += cDelay_init(this, &cDelay_dK2gfBCv, 7.645f);
  numBytes += cDelay_init(this, &cDelay_qHJVjmFc, 0.0f);
  numBytes += cBinop_init(&cBinop_omrsohxL, 7.645f); // __mul
  numBytes += cBinop_init(&cBinop_w16dV3GY, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_NUNnpmCm, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_QqZXy9NC, 0.0f); // __sub
  numBytes += cVar_init_f(&cVar_OmyZeat0, 0.0f);
  numBytes += cVar_init_f(&cVar_BFqUkZdt, 0.0f);
  numBytes += cPack_init(&cPack_vUzxNa7Q, 2, 0.0f, 50.0f);
  numBytes += cVar_init_f(&cVar_WQqzeUI6, 22050.0f);
  numBytes += cBinop_init(&cBinop_OfsniVMN, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_FqY9qwzt, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rpVvtY5w, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_VoWNtNBn, 22050.0f);
  numBytes += cBinop_init(&cBinop_f8HzUKSE, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_d9eekS1V, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QLavkFjC, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_0Ql1vxro, 22050.0f);
  numBytes += cBinop_init(&cBinop_zJpwbBRX, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_cSCNr5LN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ARZ35i2H, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_zMPQ7yMT, 0.0f);
  numBytes += cVar_init_f(&cVar_jUq8fEyy, 1000.0f);
  numBytes += cBinop_init(&cBinop_qnmONYi4, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_YhdzLPtL, 0.0f);
  numBytes += cVar_init_f(&cVar_aZFYGOL4, 0.0f);
  numBytes += cIf_init(&cIf_rZqOfbUa, false);
  numBytes += cDelay_init(this, &cDelay_xk3laogU, 0.0f);
  numBytes += cDelay_init(this, &cDelay_NWcGrMHG, 0.0f);
  numBytes += hTable_init(&hTable_NpNlKGon, 256);
  numBytes += cTabhead_init(&cTabhead_IUQqaRy9, &hTable_NpNlKGon);
  numBytes += cVar_init_s(&cVar_5prN7IYv, "del-1001-del1");
  numBytes += cDelay_init(this, &cDelay_PJiOm9TI, 150.0f);
  numBytes += cDelay_init(this, &cDelay_yfzXyLrh, 0.0f);
  numBytes += cBinop_init(&cBinop_Jswl3Cab, 150.0f); // __mul
  numBytes += cBinop_init(&cBinop_Qs0ZNzKE, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_yK6Z6Xdn, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_LkFDHgTm, 0.0f); // __sub
  numBytes += cVar_init_f(&cVar_gAw5Efmi, 0.0f);
  numBytes += cVar_init_f(&cVar_IeF8WKaC, 0.0f);
  numBytes += cVar_init_f(&cVar_KnY69inE, 0.0f);
  numBytes += cVar_init_f(&cVar_WA3kYTMG, 0.0f);
  numBytes += cVar_init_f(&cVar_fxaE9vpq, 0.0f);
  numBytes += cVar_init_f(&cVar_foJcGGTd, 0.0f);
  numBytes += cIf_init(&cIf_58ZW9mbc, false);
  numBytes += cVar_init_f(&cVar_59R8Ii3u, 0.0f);
  numBytes += cIf_init(&cIf_lUXrF3Oi, false);
  numBytes += cSlice_init(&cSlice_9hWjDD2b, 1, -1);
  numBytes += cSlice_init(&cSlice_uLP4MPv6, 1, -1);
  numBytes += cVar_init_f(&cVar_zgVuiF7H, 0.0f);
  numBytes += cIf_init(&cIf_kGjgWGfy, false);
  numBytes += cBinop_init(&cBinop_xPOTMvFf, 0.0f); // __neq
  numBytes += cIf_init(&cIf_RDYFTCpJ, false);
  numBytes += cIf_init(&cIf_zKP2urHc, false);
  numBytes += cIf_init(&cIf_zTdbgkHK, false);
  numBytes += cIf_init(&cIf_7FyueW7f, true);
  numBytes += cIf_init(&cIf_1cfsMPRp, false);
  numBytes += sVarf_init(&sVarf_oIfxBiP6, 1.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_0LRjEbnW, 4.0f); // __unimod
  numBytes += sVarf_init(&sVarf_XEB4jDt2, 0.1f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_E1hKMInb, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_IuIrIB46, 0.0f); // __add
  numBytes += sVarf_init(&sVarf_jZbszGbo, 0.65f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2OPSV9yg, 0.55f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_mEczP16U, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_nxXhdqQc, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_TsUsgWBZ, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_0jB2bvVX, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_AN7R2O3h, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_GPohGfZH, 0.0f); // __add
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_ChaffVerb::~Heavy_ChaffVerb() {
  cPack_free(&cPack_A0BbPB1B);
  cPack_free(&cPack_MqBJXvUs);
  hTable_free(&hTable_etljesG5);
  hTable_free(&hTable_lSqA0hGM);
  hTable_free(&hTable_0OecdYhI);
  hTable_free(&hTable_8BLh59FN);
  hTable_free(&hTable_yw0or66v);
  cPack_free(&cPack_YycXJJha);
  cPack_free(&cPack_2bA5qlVC);
  hTable_free(&hTable_JcPJtdX8);
  hTable_free(&hTable_lwJzjTGw);
  hTable_free(&hTable_UQoOOfNl);
  hTable_free(&hTable_OQfvzmDE);
  hTable_free(&hTable_VrejEx9y);
  hTable_free(&hTable_TFIvtNDB);
  cPack_free(&cPack_vUzxNa7Q);
  hTable_free(&hTable_NpNlKGon);
}

HvTable *Heavy_ChaffVerb::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0xA1445E2C: return &hTable_etljesG5; // del-1002-shifter
    case 0xAAA0EB60: return &hTable_lSqA0hGM; // del-1052-del1
    case 0xA2AC524D: return &hTable_0OecdYhI; // del-1052-del2
    case 0xE36A35B: return &hTable_8BLh59FN; // del-1052-del3
    case 0x48CE0509: return &hTable_yw0or66v; // del-1052-del4
    case 0xE34D6E72: return &hTable_JcPJtdX8; // del-1052-ref1
    case 0x6A1027AB: return &hTable_lwJzjTGw; // del-1052-ref2
    case 0xA37C6D49: return &hTable_UQoOOfNl; // del-1052-ref3
    case 0xCEFE5FE5: return &hTable_OQfvzmDE; // del-1052-ref4
    case 0x48EB8BBB: return &hTable_VrejEx9y; // del-1052-ref6
    case 0xCC6F73D5: return &hTable_TFIvtNDB; // del-1052-ref5
    case 0xED65564F: return &hTable_NpNlKGon; // del-1001-del1
    default: return nullptr;
  }
}

void Heavy_ChaffVerb::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0x1F30993F: { // A__LFO_Period
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7EZsLRIm_sendMessage);
      break;
    }
    case 0x1A2B8E9F: { // A__LFO_Steps_Scale__Type2
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GATK0CxN_sendMessage);
      break;
    }
    case 0xBE3344C8: { // A__LFO_Steps__Type2
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XCQD18R8_sendMessage);
      break;
    }
    case 0x7369936E: { // A__LFO_Switch
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mfZmkl1P_sendMessage);
      break;
    }
    case 0xD64CFD23: { // A__LFO_type
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iqoTcYmZ_sendMessage);
      break;
    }
    case 0x51447E19: { // B__General_Offset
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eY41Qemk_sendMessage);
      break;
    }
    case 0xA10FCFC4: { // B__General_Scale
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ODmFsjRj_sendMessage);
      break;
    }
    case 0x7EFB8E46: { // C__Random_LFO_Offset
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4F2uLaUK_sendMessage);
      break;
    }
    case 0xE6223016: { // C__Random_LFO_Period
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iffMoq8w_sendMessage);
      break;
    }
    case 0x3281900D: { // C__Random_LFO_Scale
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JhROtCwj_sendMessage);
      break;
    }
    case 0x6150BC53: { // C__Random_LFO_Switch
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2bCaFxqj_sendMessage);
      break;
    }
    case 0x9CBB1BF3: { // D__Shift_Microtone
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_btGfvAme_sendMessage);
      break;
    }
    case 0x4439D71: { // D__Shift_Transpose
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_22QwyOO1_sendMessage);
      break;
    }
    case 0x890283C2: { // E__Fx_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MMEkQhWo_sendMessage);
      break;
    }
    case 0x12962685: { // E__HiPass_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tWGDq7C6_sendMessage);
      break;
    }
    case 0x183CFEE5: { // E__Shift_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_EruxOk1F_sendMessage);
      break;
    }
    case 0x57FF40DB: { // E__Shift_Window
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZreJBCML_sendMessage);
      break;
    }
    case 0x69A91334: { // F__FX_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fqCkZ6ZE_sendMessage);
      break;
    }
    case 0x68D029F7: { // F__FX_Delay_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_m3uXQ87J_sendMessage);
      break;
    }
    case 0xD63693D0: { // Mix__Dry_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_I2QqTtZI_sendMessage);
      break;
    }
    case 0x1FC3C02C: { // Mix__Dry_Vol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XYQesTDN_sendMessage);
      break;
    }
    case 0x58653D84: { // Mix__Reverb_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sD4P3ECJ_sendMessage);
      break;
    }
    case 0xE764F673: { // Mix__Reverb_Vol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_S0sG2IoD_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PyyMWJsu_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_ChaffVerb::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "A__LFO_Period";
        info->hash = 0x1F30993F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1500.0f;
        break;
      }
      case 1: {
        info->name = "A__LFO_Steps_Scale__Type2";
        info->hash = 0x1A2B8E9F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -5.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 2: {
        info->name = "A__LFO_Steps__Type2";
        info->hash = 0xBE3344C8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 10.0f;
        info->defaultVal = 4.0f;
        break;
      }
      case 3: {
        info->name = "A__LFO_Switch";
        info->hash = 0x7369936E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "A__LFO_type";
        info->hash = 0xD64CFD23;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 2.99f;
        info->defaultVal = 0.0f;
        break;
      }
      case 5: {
        info->name = "B__General_Offset";
        info->hash = 0x51447E19;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -2.0f;
        info->maxVal = 2.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 6: {
        info->name = "B__General_Scale";
        info->hash = 0xA10FCFC4;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -7.0f;
        info->maxVal = 7.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 7: {
        info->name = "C__Random_LFO_Offset";
        info->hash = 0x7EFB8E46;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -2.0f;
        info->maxVal = 2.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "C__Random_LFO_Period";
        info->hash = 0xE6223016;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1500.0f;
        break;
      }
      case 9: {
        info->name = "C__Random_LFO_Scale";
        info->hash = 0x3281900D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -7.0f;
        info->maxVal = 7.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 10: {
        info->name = "C__Random_LFO_Switch";
        info->hash = 0x6150BC53;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 11: {
        info->name = "D__Shift_Microtone";
        info->hash = 0x9CBB1BF3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -1.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "D__Shift_Transpose";
        info->hash = 0x4439D71;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -36.0f;
        info->maxVal = 36.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 13: {
        info->name = "E__Fx_Level";
        info->hash = 0x890283C2;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.7f;
        break;
      }
      case 14: {
        info->name = "E__HiPass_Freq";
        info->hash = 0x12962685;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 100.0f;
        info->maxVal = 2500.0f;
        info->defaultVal = 800.0f;
        break;
      }
      case 15: {
        info->name = "E__Shift_Delay";
        info->hash = 0x183CFEE5;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 500.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 16: {
        info->name = "E__Shift_Window";
        info->hash = 0x57FF40DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 3500.0f;
        info->defaultVal = 1000.0f;
        break;
      }
      case 17: {
        info->name = "F__FX_Delay";
        info->hash = 0x69A91334;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 2000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 18: {
        info->name = "F__FX_Delay_Feedback";
        info->hash = 0x68D029F7;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.97f;
        info->defaultVal = 0.65f;
        break;
      }
      case 19: {
        info->name = "Mix__Dry_Mix";
        info->hash = 0xD63693D0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.45f;
        break;
      }
      case 20: {
        info->name = "Mix__Dry_Vol";
        info->hash = 0x1FC3C02C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.1f;
        break;
      }
      case 21: {
        info->name = "Mix__Reverb_Level";
        info->hash = 0x58653D84;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.85f;
        break;
      }
      case 22: {
        info->name = "Mix__Reverb_Vol";
        info->hash = 0xE764F673;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.5f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 23;
}



/*
 * Send Function Implementations
 */


void Heavy_ChaffVerb::cVar_HZRlSvUa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.05776f, 0, m, &cBinop_t5C1hIjm_sendMessage);
}

void Heavy_ChaffVerb::cVar_4uhoE5nR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_JZ2JbrL4_sendMessage);
}

void Heavy_ChaffVerb::cPack_A0BbPB1B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_1cpZyiXb, 0, m, NULL);
}

void Heavy_ChaffVerb::cUnop_kKCq75NQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wwKkTi9h, 0, m, &cVar_wwKkTi9h_sendMessage);
}

void Heavy_ChaffVerb::cBinop_vBA0StjI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_EXP, m, &cUnop_kKCq75NQ_sendMessage);
}

void Heavy_ChaffVerb::cVar_wwKkTi9h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_8KS7Wink_sendMessage);
}

void Heavy_ChaffVerb::cPack_MqBJXvUs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_E6P7DZ0d, 0, m, NULL);
}

void Heavy_ChaffVerb::cVar_3WsMvqbI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.5f, 0, m, &cBinop_PcfX3OOy_sendMessage);
}

void Heavy_ChaffVerb::cVar_xNHKKgnq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_Edfdcaxi, 0, m);
}

void Heavy_ChaffVerb::cMsg_rvQdpH1U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_OuLoWFHs_sendMessage);
}

void Heavy_ChaffVerb::cSystem_OuLoWFHs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_QbMN59Nd_sendMessage);
}

void Heavy_ChaffVerb::cDelay_WMWWDyaA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_WMWWDyaA, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_QfVinwBa, 0, m, &cDelay_QfVinwBa_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_WMWWDyaA, 0, m, &cDelay_WMWWDyaA_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_p4H0tNBb, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_QfVinwBa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_QfVinwBa, m);
  cMsg_hBf44RvI_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_2F5WBaIl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_weBnraNR_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_AhqF4Wug_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ro92XAML_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_etljesG5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qiEpKkiy_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_WMWWDyaA, 2, m, &cDelay_WMWWDyaA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Kj8K5c3T_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ro92XAML_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_etljesG5, 0, m, &hTable_etljesG5_sendMessage);
}

void Heavy_ChaffVerb::cBinop_QbMN59Nd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_AhqF4Wug_sendMessage);
}

void Heavy_ChaffVerb::cMsg_hBf44RvI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_etljesG5, 0, m, &hTable_etljesG5_sendMessage);
}

void Heavy_ChaffVerb::cCast_Kj8K5c3T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_WMWWDyaA, 0, m, &cDelay_WMWWDyaA_sendMessage);
}

void Heavy_ChaffVerb::cMsg_qiEpKkiy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_QfVinwBa, 2, m, &cDelay_QfVinwBa_sendMessage);
}

void Heavy_ChaffVerb::cMsg_weBnraNR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_p4H0tNBb, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_1qadGV3Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_wVmX5sX6_sendMessage);
}

void Heavy_ChaffVerb::cSystem_wVmX5sX6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_uCC8BXOx_sendMessage);
}

void Heavy_ChaffVerb::cVar_YZjX8hmp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6surwDWd_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSystem_1kUuMKSo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_T1SptUns_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_AtsFugVf, m);
}

void Heavy_ChaffVerb::cBinop_uCC8BXOx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_5QEHi7QD, m);
}

void Heavy_ChaffVerb::cMsg_6surwDWd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_1kUuMKSo_sendMessage);
}

void Heavy_ChaffVerb::cBinop_T1SptUns_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_d3h77QEQ, m);
}

void Heavy_ChaffVerb::cMsg_tMGjiHJf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_IhGYgyKi_sendMessage);
}

void Heavy_ChaffVerb::cSystem_IhGYgyKi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_g13LHGWe_sendMessage);
}

void Heavy_ChaffVerb::cVar_GV12EERs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UEJcIXgy_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSystem_WLZ6ivVY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_kdMsHZV2_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_7WsEA8Ie, m);
}

void Heavy_ChaffVerb::cBinop_g13LHGWe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_QopkJA3T, m);
}

void Heavy_ChaffVerb::cMsg_UEJcIXgy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_WLZ6ivVY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_kdMsHZV2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_2Wh1pN0p, m);
}

void Heavy_ChaffVerb::cBinop_kNA9s8fi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xNHKKgnq, 0, m, &cVar_xNHKKgnq_sendMessage);
}

void Heavy_ChaffVerb::cBinop_4WR2eiWu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_056XsCTN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_F2YRkMcN_sendMessage);
}

void Heavy_ChaffVerb::cCast_F2YRkMcN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kNA9s8fi, HV_BINOP_DIVIDE, 0, m, &cBinop_kNA9s8fi_sendMessage);
}

void Heavy_ChaffVerb::cCast_056XsCTN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kNA9s8fi, HV_BINOP_DIVIDE, 1, m, &cBinop_kNA9s8fi_sendMessage);
}

void Heavy_ChaffVerb::cBinop_8KS7Wink_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_bvCXkPDC_sendMessage);
}

void Heavy_ChaffVerb::cBinop_t5C1hIjm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 87.3365f, 0, m, &cBinop_vBA0StjI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_bvCXkPDC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kNA9s8fi, HV_BINOP_DIVIDE, 0, m, &cBinop_kNA9s8fi_sendMessage);
}

void Heavy_ChaffVerb::cBinop_PcfX3OOy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_MqBJXvUs, 0, m, &cPack_MqBJXvUs_sendMessage);
}

void Heavy_ChaffVerb::cBinop_JZ2JbrL4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.001f, 0, m, &cBinop_4WR2eiWu_sendMessage);
  cPack_onMessage(_c, &Context(_c)->cPack_A0BbPB1B, 0, m, &cPack_A0BbPB1B_sendMessage);
}

void Heavy_ChaffVerb::cUnop_v9fE2YCx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zKP2urHc, 0, m, &cIf_zKP2urHc_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_qDXTgHkd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sms7WvGv_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sGUXwLWr_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Rz3iH9Br_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_sms7WvGv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_loB8XIn6_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cCast_sGUXwLWr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FeiBB6L6_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cCast_Rz3iH9Br_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fGxHXdjz_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_Coy7Zo0A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_2lngMseC_sendMessage);
}

void Heavy_ChaffVerb::cBinop_2lngMseC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_OHv70HmA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_wZfiiSmw_sendMessage);
}

void Heavy_ChaffVerb::cVar_2hE7623h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_a2kANdA9_sendMessage);
}

void Heavy_ChaffVerb::cMsg_5OcgfgbN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_50PJgNfD_sendMessage);
}

void Heavy_ChaffVerb::cSystem_50PJgNfD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CSQmZmOs, HV_BINOP_DIVIDE, 1, m, &cBinop_CSQmZmOs_sendMessage);
}

void Heavy_ChaffVerb::cBinop_OHv70HmA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Rs96StZQ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Rs96StZQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_0RK74LDG, m);
}

void Heavy_ChaffVerb::cMsg_82ySjEDd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_SFgeJIel_sendMessage);
}

void Heavy_ChaffVerb::cBinop_SFgeJIel_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Coy7Zo0A_sendMessage);
}

void Heavy_ChaffVerb::cBinop_wZfiiSmw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_AYADOSxP, m);
}

void Heavy_ChaffVerb::cBinop_a2kANdA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_d3XRxTu3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_d3XRxTu3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CSQmZmOs, HV_BINOP_DIVIDE, 0, m, &cBinop_CSQmZmOs_sendMessage);
}

void Heavy_ChaffVerb::cBinop_CSQmZmOs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_82ySjEDd_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_HycHHb1A_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7E64BD01: { // "seed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_VcBitlUw, 0, m, &cSlice_VcBitlUw_sendMessage);
      break;
    }
    default: {
      cRandom_onMessage(_c, &Context(_c)->cRandom_SLfCZAiH, 0, m, &cRandom_SLfCZAiH_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_qYdLXGAJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_TmTT5sWa_sendMessage);
}

void Heavy_ChaffVerb::cUnop_TmTT5sWa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 50.0f, 0, m, &cBinop_zWC3ScTb_sendMessage);
}

void Heavy_ChaffVerb::cRandom_SLfCZAiH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 100.0f, 0, m, &cBinop_qYdLXGAJ_sendMessage);
}

void Heavy_ChaffVerb::cSlice_VcBitlUw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cRandom_onMessage(_c, &Context(_c)->cRandom_SLfCZAiH, 1, m, &cRandom_SLfCZAiH_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cSwitchcase_YJAt0eez_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_fvdtHIfV_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_fvdtHIfV_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GW5WjBfU_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cDelay_MvgLe4KY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_MvgLe4KY, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_MvgLe4KY, 0, m, &cDelay_MvgLe4KY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YhdzLPtL, 0, m, &cVar_YhdzLPtL_sendMessage);
}

void Heavy_ChaffVerb::cCast_GW5WjBfU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fvdtHIfV_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_MvgLe4KY, 0, m, &cDelay_MvgLe4KY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YhdzLPtL, 0, m, &cVar_YhdzLPtL_sendMessage);
}

void Heavy_ChaffVerb::cMsg_J84fwcle_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Mq3qYe8t_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Mq3qYe8t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_6Th86m5I_sendMessage);
}

void Heavy_ChaffVerb::cVar_19ByyUfF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UhoDhSrX, HV_BINOP_MULTIPLY, 0, m, &cBinop_UhoDhSrX_sendMessage);
}

void Heavy_ChaffVerb::cMsg_fvdtHIfV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_MvgLe4KY, 0, m, &cDelay_MvgLe4KY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_rL8zbQ6V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_MvgLe4KY, 2, m, &cDelay_MvgLe4KY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_6Th86m5I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UhoDhSrX, HV_BINOP_MULTIPLY, 1, m, &cBinop_UhoDhSrX_sendMessage);
}

void Heavy_ChaffVerb::cBinop_UhoDhSrX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_rL8zbQ6V_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_nkRsEUzG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WUyYgtXd, HV_BINOP_SUBTRACT, 0, m, &cBinop_WUyYgtXd_sendMessage);
}

void Heavy_ChaffVerb::cMsg_iHCjHls0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_jiSqDD6u_sendMessage);
}

void Heavy_ChaffVerb::cSystem_jiSqDD6u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_uMpPBlND_sendMessage);
}

void Heavy_ChaffVerb::cVar_zGjdzP6I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_z9Qxin4R_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_4aK47lkA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4aK47lkA, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_YsKyTDLn, 0, m, &cDelay_YsKyTDLn_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_YdYzQAAo, 0, m, &sTabread_YdYzQAAo_sendMessage);
}

void Heavy_ChaffVerb::cDelay_YsKyTDLn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_YsKyTDLn, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_YdYzQAAo, 0, m, &sTabread_YdYzQAAo_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_YsKyTDLn, 0, m, &cDelay_YsKyTDLn_sendMessage);
}

void Heavy_ChaffVerb::sTabread_YdYzQAAo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_yy4xNQy9, HV_BINOP_SUBTRACT, 0, m, &cBinop_yy4xNQy9_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_Xe2UV846_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jklaP2EB, HV_BINOP_MAX, 0, m, &cBinop_jklaP2EB_sendMessage);
}

void Heavy_ChaffVerb::cBinop_uMpPBlND_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Xe2UV846, HV_BINOP_MULTIPLY, 0, m, &cBinop_Xe2UV846_sendMessage);
}

void Heavy_ChaffVerb::cBinop_WUyYgtXd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qiIoHy3h_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_YdYzQAAo, 0, m, &sTabread_YdYzQAAo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zudyK2WP_sendMessage);
}

void Heavy_ChaffVerb::cSystem_qCtgLqnI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yy4xNQy9, HV_BINOP_SUBTRACT, 1, m, &cBinop_yy4xNQy9_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_YsKyTDLn, 2, m, &cDelay_YsKyTDLn_sendMessage);
}

void Heavy_ChaffVerb::cMsg_z9Qxin4R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_qCtgLqnI_sendMessage);
}

void Heavy_ChaffVerb::cMsg_qiIoHy3h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_4aK47lkA, 0, m, &cDelay_4aK47lkA_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_YsKyTDLn, 0, m, &cDelay_YsKyTDLn_sendMessage);
}

void Heavy_ChaffVerb::cMsg_d7UEgPIY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_jklaP2EB, HV_BINOP_MAX, 1, m, &cBinop_jklaP2EB_sendMessage);
}

void Heavy_ChaffVerb::cBinop_jklaP2EB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WUyYgtXd, HV_BINOP_SUBTRACT, 1, m, &cBinop_WUyYgtXd_sendMessage);
}

void Heavy_ChaffVerb::cCast_zudyK2WP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4aK47lkA, 0, m, &cDelay_4aK47lkA_sendMessage);
}

void Heavy_ChaffVerb::cBinop_UQItn2Oc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4aK47lkA, 2, m, &cDelay_4aK47lkA_sendMessage);
}

void Heavy_ChaffVerb::cBinop_yy4xNQy9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_UQItn2Oc_sendMessage);
}

void Heavy_ChaffVerb::cCast_7WH2YMjb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zGjdzP6I, 0, m, &cVar_zGjdzP6I_sendMessage);
  cMsg_iHCjHls0_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_nkRsEUzG, 0, m, &cTabhead_nkRsEUzG_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_fEDGYWso_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xGXeQUTd, HV_BINOP_SUBTRACT, 0, m, &cBinop_xGXeQUTd_sendMessage);
}

void Heavy_ChaffVerb::cMsg_FSf7GyfT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_bug1UE9b_sendMessage);
}

void Heavy_ChaffVerb::cSystem_bug1UE9b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_akJHtVNw_sendMessage);
}

void Heavy_ChaffVerb::cVar_l7yxOHqT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6cruKUaW_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_vyvA5Ior_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_vyvA5Ior, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_OFUiwHHd, 0, m, &cDelay_OFUiwHHd_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_dp5qrxkc, 0, m, &sTabread_dp5qrxkc_sendMessage);
}

void Heavy_ChaffVerb::cDelay_OFUiwHHd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_OFUiwHHd, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_dp5qrxkc, 0, m, &sTabread_dp5qrxkc_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_OFUiwHHd, 0, m, &cDelay_OFUiwHHd_sendMessage);
}

void Heavy_ChaffVerb::sTabread_dp5qrxkc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_Nn2wTKBg, HV_BINOP_SUBTRACT, 0, m, &cBinop_Nn2wTKBg_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_fRy8PljG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SHNQp9sW, HV_BINOP_MAX, 0, m, &cBinop_SHNQp9sW_sendMessage);
}

void Heavy_ChaffVerb::cBinop_akJHtVNw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fRy8PljG, HV_BINOP_MULTIPLY, 0, m, &cBinop_fRy8PljG_sendMessage);
}

void Heavy_ChaffVerb::cBinop_xGXeQUTd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dL3aVtht_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_dp5qrxkc, 0, m, &sTabread_dp5qrxkc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vzZWG5jD_sendMessage);
}

void Heavy_ChaffVerb::cSystem_tacM82s0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Nn2wTKBg, HV_BINOP_SUBTRACT, 1, m, &cBinop_Nn2wTKBg_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_OFUiwHHd, 2, m, &cDelay_OFUiwHHd_sendMessage);
}

void Heavy_ChaffVerb::cMsg_6cruKUaW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_tacM82s0_sendMessage);
}

void Heavy_ChaffVerb::cMsg_dL3aVtht_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_vyvA5Ior, 0, m, &cDelay_vyvA5Ior_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_OFUiwHHd, 0, m, &cDelay_OFUiwHHd_sendMessage);
}

void Heavy_ChaffVerb::cMsg_lciJZgSY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_SHNQp9sW, HV_BINOP_MAX, 1, m, &cBinop_SHNQp9sW_sendMessage);
}

void Heavy_ChaffVerb::cBinop_SHNQp9sW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xGXeQUTd, HV_BINOP_SUBTRACT, 1, m, &cBinop_xGXeQUTd_sendMessage);
}

void Heavy_ChaffVerb::cCast_vzZWG5jD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_vyvA5Ior, 0, m, &cDelay_vyvA5Ior_sendMessage);
}

void Heavy_ChaffVerb::cBinop_sMgCwlVH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_vyvA5Ior, 2, m, &cDelay_vyvA5Ior_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Nn2wTKBg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_sMgCwlVH_sendMessage);
}

void Heavy_ChaffVerb::cCast_LARdSwzD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_l7yxOHqT, 0, m, &cVar_l7yxOHqT_sendMessage);
  cMsg_FSf7GyfT_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_fEDGYWso, 0, m, &cTabhead_fEDGYWso_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_7RjnzB0n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rOaKjcLJ, HV_BINOP_SUBTRACT, 0, m, &cBinop_rOaKjcLJ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_0CRJFHIe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ifbmZvLR_sendMessage);
}

void Heavy_ChaffVerb::cSystem_ifbmZvLR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ypJOWfzw_sendMessage);
}

void Heavy_ChaffVerb::cVar_5NxGnck5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_F6FNZPPZ_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_2uIw1SdJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2uIw1SdJ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_RhlFQfzT, 0, m, &cDelay_RhlFQfzT_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_hwpN1FVr, 0, m, &sTabread_hwpN1FVr_sendMessage);
}

void Heavy_ChaffVerb::cDelay_RhlFQfzT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_RhlFQfzT, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_hwpN1FVr, 0, m, &sTabread_hwpN1FVr_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_RhlFQfzT, 0, m, &cDelay_RhlFQfzT_sendMessage);
}

void Heavy_ChaffVerb::sTabread_hwpN1FVr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_uzcyQO7X, HV_BINOP_SUBTRACT, 0, m, &cBinop_uzcyQO7X_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_oaFbyvir_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_66jm88Vq, HV_BINOP_MAX, 0, m, &cBinop_66jm88Vq_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ypJOWfzw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oaFbyvir, HV_BINOP_MULTIPLY, 0, m, &cBinop_oaFbyvir_sendMessage);
}

void Heavy_ChaffVerb::cBinop_rOaKjcLJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BM4CBYlY_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_hwpN1FVr, 0, m, &sTabread_hwpN1FVr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zARi1zXR_sendMessage);
}

void Heavy_ChaffVerb::cSystem_ApXcFR3K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uzcyQO7X, HV_BINOP_SUBTRACT, 1, m, &cBinop_uzcyQO7X_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_RhlFQfzT, 2, m, &cDelay_RhlFQfzT_sendMessage);
}

void Heavy_ChaffVerb::cMsg_F6FNZPPZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ApXcFR3K_sendMessage);
}

void Heavy_ChaffVerb::cMsg_BM4CBYlY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_2uIw1SdJ, 0, m, &cDelay_2uIw1SdJ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_RhlFQfzT, 0, m, &cDelay_RhlFQfzT_sendMessage);
}

void Heavy_ChaffVerb::cMsg_H34mlmYC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_66jm88Vq, HV_BINOP_MAX, 1, m, &cBinop_66jm88Vq_sendMessage);
}

void Heavy_ChaffVerb::cBinop_66jm88Vq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rOaKjcLJ, HV_BINOP_SUBTRACT, 1, m, &cBinop_rOaKjcLJ_sendMessage);
}

void Heavy_ChaffVerb::cCast_zARi1zXR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_2uIw1SdJ, 0, m, &cDelay_2uIw1SdJ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_fofCltdf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_2uIw1SdJ, 2, m, &cDelay_2uIw1SdJ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_uzcyQO7X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_fofCltdf_sendMessage);
}

void Heavy_ChaffVerb::cCast_uVePE8K3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5NxGnck5, 0, m, &cVar_5NxGnck5_sendMessage);
  cMsg_0CRJFHIe_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_7RjnzB0n, 0, m, &cTabhead_7RjnzB0n_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_cFqrwKXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mqhPETdP, HV_BINOP_SUBTRACT, 0, m, &cBinop_mqhPETdP_sendMessage);
}

void Heavy_ChaffVerb::cMsg_z5JbvRpw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_hc5OLJqA_sendMessage);
}

void Heavy_ChaffVerb::cSystem_hc5OLJqA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_M67mBejy_sendMessage);
}

void Heavy_ChaffVerb::cVar_QhGLWWzl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ik2LMBrV_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_anqj1Vt7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_anqj1Vt7, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qSVDzd9I, 0, m, &cDelay_qSVDzd9I_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_bgxyfHM0, 0, m, &sTabread_bgxyfHM0_sendMessage);
}

void Heavy_ChaffVerb::cDelay_qSVDzd9I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_qSVDzd9I, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_bgxyfHM0, 0, m, &sTabread_bgxyfHM0_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qSVDzd9I, 0, m, &cDelay_qSVDzd9I_sendMessage);
}

void Heavy_ChaffVerb::sTabread_bgxyfHM0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_N6yiBXMF, HV_BINOP_SUBTRACT, 0, m, &cBinop_N6yiBXMF_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_e2qevqGT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eHpIOeQN, HV_BINOP_MAX, 0, m, &cBinop_eHpIOeQN_sendMessage);
}

void Heavy_ChaffVerb::cBinop_M67mBejy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_e2qevqGT, HV_BINOP_MULTIPLY, 0, m, &cBinop_e2qevqGT_sendMessage);
}

void Heavy_ChaffVerb::cBinop_mqhPETdP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nRTQJCxA_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_bgxyfHM0, 0, m, &sTabread_bgxyfHM0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rl0KeNqv_sendMessage);
}

void Heavy_ChaffVerb::cSystem_AlZ4ygIU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_N6yiBXMF, HV_BINOP_SUBTRACT, 1, m, &cBinop_N6yiBXMF_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qSVDzd9I, 2, m, &cDelay_qSVDzd9I_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Ik2LMBrV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_AlZ4ygIU_sendMessage);
}

void Heavy_ChaffVerb::cMsg_nRTQJCxA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_anqj1Vt7, 0, m, &cDelay_anqj1Vt7_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qSVDzd9I, 0, m, &cDelay_qSVDzd9I_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ghGqKZHQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_eHpIOeQN, HV_BINOP_MAX, 1, m, &cBinop_eHpIOeQN_sendMessage);
}

void Heavy_ChaffVerb::cBinop_eHpIOeQN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mqhPETdP, HV_BINOP_SUBTRACT, 1, m, &cBinop_mqhPETdP_sendMessage);
}

void Heavy_ChaffVerb::cCast_rl0KeNqv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_anqj1Vt7, 0, m, &cDelay_anqj1Vt7_sendMessage);
}

void Heavy_ChaffVerb::cBinop_h3FEVPG9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_anqj1Vt7, 2, m, &cDelay_anqj1Vt7_sendMessage);
}

void Heavy_ChaffVerb::cBinop_N6yiBXMF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_h3FEVPG9_sendMessage);
}

void Heavy_ChaffVerb::cCast_MMTQnlWA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QhGLWWzl, 0, m, &cVar_QhGLWWzl_sendMessage);
  cMsg_z5JbvRpw_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_cFqrwKXc, 0, m, &cTabhead_cFqrwKXc_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ak8IcJrK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_FvWDemum_sendMessage);
}

void Heavy_ChaffVerb::cSystem_FvWDemum_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_zwdKa0BM_sendMessage);
}

void Heavy_ChaffVerb::cDelay_VUxNpfSq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_VUxNpfSq, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_njJpeKpX, 0, m, &cDelay_njJpeKpX_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VUxNpfSq, 0, m, &cDelay_VUxNpfSq_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_72K7vOpf, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_njJpeKpX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_njJpeKpX, m);
  cMsg_DqkvHvUM_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_v09VMWXH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_yScHEmsz_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_S6KZ2hBa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_W4MDAic7_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_lSqA0hGM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iaO03Def_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VUxNpfSq, 2, m, &cDelay_VUxNpfSq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZfgbtcIj_sendMessage);
}

void Heavy_ChaffVerb::cMsg_W4MDAic7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_lSqA0hGM, 0, m, &hTable_lSqA0hGM_sendMessage);
}

void Heavy_ChaffVerb::cBinop_zwdKa0BM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 58.6435f, 0, m, &cBinop_S6KZ2hBa_sendMessage);
}

void Heavy_ChaffVerb::cMsg_DqkvHvUM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_lSqA0hGM, 0, m, &hTable_lSqA0hGM_sendMessage);
}

void Heavy_ChaffVerb::cCast_ZfgbtcIj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_VUxNpfSq, 0, m, &cDelay_VUxNpfSq_sendMessage);
}

void Heavy_ChaffVerb::cMsg_iaO03Def_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_njJpeKpX, 2, m, &cDelay_njJpeKpX_sendMessage);
}

void Heavy_ChaffVerb::cMsg_yScHEmsz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_72K7vOpf, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_6hq4GrT2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_vPR35buV_sendMessage);
}

void Heavy_ChaffVerb::cSystem_vPR35buV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_qxtN8ezK_sendMessage);
}

void Heavy_ChaffVerb::cDelay_Sofg59Fp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Sofg59Fp, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_t1TKGA17, 0, m, &cDelay_t1TKGA17_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Sofg59Fp, 0, m, &cDelay_Sofg59Fp_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_mLOgGEWK, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_t1TKGA17_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_t1TKGA17, m);
  cMsg_c5crcJv4_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_zwjW9cwj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_I8vWpI01_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_UaXnasND_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wzM8ts7o_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_0OecdYhI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kqZEVRB6_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Sofg59Fp, 2, m, &cDelay_Sofg59Fp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XLU0B9ao_sendMessage);
}

void Heavy_ChaffVerb::cMsg_wzM8ts7o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_0OecdYhI, 0, m, &hTable_0OecdYhI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qxtN8ezK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 69.4325f, 0, m, &cBinop_UaXnasND_sendMessage);
}

void Heavy_ChaffVerb::cMsg_c5crcJv4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_0OecdYhI, 0, m, &hTable_0OecdYhI_sendMessage);
}

void Heavy_ChaffVerb::cCast_XLU0B9ao_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Sofg59Fp, 0, m, &cDelay_Sofg59Fp_sendMessage);
}

void Heavy_ChaffVerb::cMsg_kqZEVRB6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_t1TKGA17, 2, m, &cDelay_t1TKGA17_sendMessage);
}

void Heavy_ChaffVerb::cMsg_I8vWpI01_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_mLOgGEWK, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_cVxz00gk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_6VS0xOQ0_sendMessage);
}

void Heavy_ChaffVerb::cSystem_6VS0xOQ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_nv6Jah5E_sendMessage);
}

void Heavy_ChaffVerb::cDelay_sBZZmcod_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_sBZZmcod, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_E9ntm5BC, 0, m, &cDelay_E9ntm5BC_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_sBZZmcod, 0, m, &cDelay_sBZZmcod_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_7QhySYme, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_E9ntm5BC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_E9ntm5BC, m);
  cMsg_tQPiyFvp_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_JxmR3vTl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_ZgBwOMIc_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_sGO7koJE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mab7suAc_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_8BLh59FN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pD7AO8bu_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_sBZZmcod, 2, m, &cDelay_sBZZmcod_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RZg7aBd8_sendMessage);
}

void Heavy_ChaffVerb::cMsg_mab7suAc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_8BLh59FN, 0, m, &hTable_8BLh59FN_sendMessage);
}

void Heavy_ChaffVerb::cBinop_nv6Jah5E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 74.5234f, 0, m, &cBinop_sGO7koJE_sendMessage);
}

void Heavy_ChaffVerb::cMsg_tQPiyFvp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_8BLh59FN, 0, m, &hTable_8BLh59FN_sendMessage);
}

void Heavy_ChaffVerb::cCast_RZg7aBd8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_sBZZmcod, 0, m, &cDelay_sBZZmcod_sendMessage);
}

void Heavy_ChaffVerb::cMsg_pD7AO8bu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_E9ntm5BC, 2, m, &cDelay_E9ntm5BC_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ZgBwOMIc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_7QhySYme, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_uaqeeZFi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_HdDjT9LG_sendMessage);
}

void Heavy_ChaffVerb::cSystem_HdDjT9LG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ezid0K0P_sendMessage);
}

void Heavy_ChaffVerb::cDelay_FnBZAHs3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_FnBZAHs3, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_NYQpO74l, 0, m, &cDelay_NYQpO74l_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FnBZAHs3, 0, m, &cDelay_FnBZAHs3_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_voKIXw9m, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_NYQpO74l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_NYQpO74l, m);
  cMsg_3NTMSN6b_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_3nuhJvvI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_tbS01gdH_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_WJN9XOPo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_I97Z3orq_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_yw0or66v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DefAZq96_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FnBZAHs3, 2, m, &cDelay_FnBZAHs3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Q4EEhi51_sendMessage);
}

void Heavy_ChaffVerb::cMsg_I97Z3orq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_yw0or66v, 0, m, &hTable_yw0or66v_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ezid0K0P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 86.1244f, 0, m, &cBinop_WJN9XOPo_sendMessage);
}

void Heavy_ChaffVerb::cMsg_3NTMSN6b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_yw0or66v, 0, m, &hTable_yw0or66v_sendMessage);
}

void Heavy_ChaffVerb::cCast_Q4EEhi51_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_FnBZAHs3, 0, m, &cDelay_FnBZAHs3_sendMessage);
}

void Heavy_ChaffVerb::cMsg_DefAZq96_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_NYQpO74l, 2, m, &cDelay_NYQpO74l_sendMessage);
}

void Heavy_ChaffVerb::cMsg_tbS01gdH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_voKIXw9m, 1, m, NULL);
}

void Heavy_ChaffVerb::cPack_YycXJJha_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_hny6jqOl, 0, m, NULL);
}

void Heavy_ChaffVerb::cPack_2bA5qlVC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_dun5Gj9V, 0, m, NULL);
}

void Heavy_ChaffVerb::cBinop_2dSwGmAZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_T4FzDEdH_sendMessage);
}

void Heavy_ChaffVerb::cBinop_T4FzDEdH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 200.0f, 0, m, &cBinop_QGvGkjGn_sendMessage);
}

void Heavy_ChaffVerb::cVar_LVg039Zy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GfrukEvS, HV_BINOP_MULTIPLY, 0, m, &cBinop_GfrukEvS_sendMessage);
}

void Heavy_ChaffVerb::cMsg_i9RXI1pV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_O5S569Cw_sendMessage);
}

void Heavy_ChaffVerb::cSystem_O5S569Cw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DmADGokQ_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_GfrukEvS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_vS7puXO2_sendMessage);
}

void Heavy_ChaffVerb::cBinop_kf9hT6TT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GfrukEvS, HV_BINOP_MULTIPLY, 1, m, &cBinop_GfrukEvS_sendMessage);
}

void Heavy_ChaffVerb::cMsg_DmADGokQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_kf9hT6TT_sendMessage);
}

void Heavy_ChaffVerb::cBinop_vS7puXO2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_zMyhNeA4_sendMessage);
}

void Heavy_ChaffVerb::cBinop_zMyhNeA4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_cPljsI6z_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_zhSdwg0C, m);
}

void Heavy_ChaffVerb::cBinop_cPljsI6z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_jRVRQoZd, m);
}

void Heavy_ChaffVerb::cVar_F04CV4Qc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.125f, 0, m, &cBinop_MFFYqgne_sendMessage);
}

void Heavy_ChaffVerb::cVar_EmlW1xcy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_2dSwGmAZ_sendMessage);
}

void Heavy_ChaffVerb::cVar_bXzBsHfY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN_EQL, 1.0f, 0, m, &cBinop_R5T4i2dA_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_7l6qkrcS, 0, m, &cIf_7l6qkrcS_sendMessage);
}

void Heavy_ChaffVerb::cVar_9VRQfEbG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_OlUIuJgI_sendMessage);
}

void Heavy_ChaffVerb::cIf_7l6qkrcS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_qV7pLj5S_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_OmyZeat0, 0, m, &cVar_OmyZeat0_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_R5T4i2dA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7l6qkrcS, 1, m, &cIf_7l6qkrcS_sendMessage);
}

void Heavy_ChaffVerb::cBinop_OlUIuJgI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_BcMTB5EY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_BcMTB5EY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BFqUkZdt, 0, m, &cVar_BFqUkZdt_sendMessage);
}

void Heavy_ChaffVerb::cMsg_rRgk1knQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7B8o95Jo_sendMessage);
}

void Heavy_ChaffVerb::cSystem_7B8o95Jo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ogRzMcHb_sendMessage);
}

void Heavy_ChaffVerb::cDelay_NNdei6j5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_NNdei6j5, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_9DCojqVw, 0, m, &cDelay_9DCojqVw_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_NNdei6j5, 0, m, &cDelay_NNdei6j5_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_EyVrZebd, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_9DCojqVw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9DCojqVw, m);
  cMsg_kSnPTWo6_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_F9a0LR6O_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_rtclQehK_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_vkmud98q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PlaIh7O4_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_JcPJtdX8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4UHxR4Qu_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_NNdei6j5, 2, m, &cDelay_NNdei6j5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_enDaajQ0_sendMessage);
}

void Heavy_ChaffVerb::cMsg_PlaIh7O4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_JcPJtdX8, 0, m, &hTable_JcPJtdX8_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ogRzMcHb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 43.5337f, 0, m, &cBinop_vkmud98q_sendMessage);
}

void Heavy_ChaffVerb::cMsg_kSnPTWo6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_JcPJtdX8, 0, m, &hTable_JcPJtdX8_sendMessage);
}

void Heavy_ChaffVerb::cCast_enDaajQ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_NNdei6j5, 0, m, &cDelay_NNdei6j5_sendMessage);
}

void Heavy_ChaffVerb::cMsg_4UHxR4Qu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_9DCojqVw, 2, m, &cDelay_9DCojqVw_sendMessage);
}

void Heavy_ChaffVerb::cMsg_rtclQehK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_EyVrZebd, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_mB8eGBnS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WUjBnVlx, HV_BINOP_SUBTRACT, 0, m, &cBinop_WUjBnVlx_sendMessage);
}

void Heavy_ChaffVerb::cMsg_XUaPpWxe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Nr3PlbS2_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Nr3PlbS2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_GYbROhud_sendMessage);
}

void Heavy_ChaffVerb::cVar_U8HPWcfs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tBZhjuva_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_s1DDvTxv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_s1DDvTxv, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_K9JHoYFz, 0, m, &cDelay_K9JHoYFz_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_CoX3wble, 0, m, &sTabread_CoX3wble_sendMessage);
}

void Heavy_ChaffVerb::cDelay_K9JHoYFz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_K9JHoYFz, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_CoX3wble, 0, m, &sTabread_CoX3wble_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_K9JHoYFz, 0, m, &cDelay_K9JHoYFz_sendMessage);
}

void Heavy_ChaffVerb::sTabread_CoX3wble_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_DXohTEqV, HV_BINOP_SUBTRACT, 0, m, &cBinop_DXohTEqV_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_IDUOirZ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hUVy8K1b, HV_BINOP_MAX, 0, m, &cBinop_hUVy8K1b_sendMessage);
}

void Heavy_ChaffVerb::cBinop_GYbROhud_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IDUOirZ8, HV_BINOP_MULTIPLY, 0, m, &cBinop_IDUOirZ8_sendMessage);
}

void Heavy_ChaffVerb::cBinop_WUjBnVlx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8Iij703G_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_CoX3wble, 0, m, &sTabread_CoX3wble_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Up1fincS_sendMessage);
}

void Heavy_ChaffVerb::cSystem_rqj4ow8I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DXohTEqV, HV_BINOP_SUBTRACT, 1, m, &cBinop_DXohTEqV_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_K9JHoYFz, 2, m, &cDelay_K9JHoYFz_sendMessage);
}

void Heavy_ChaffVerb::cMsg_tBZhjuva_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_rqj4ow8I_sendMessage);
}

void Heavy_ChaffVerb::cMsg_8Iij703G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_s1DDvTxv, 0, m, &cDelay_s1DDvTxv_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_K9JHoYFz, 0, m, &cDelay_K9JHoYFz_sendMessage);
}

void Heavy_ChaffVerb::cMsg_XY8Rds3D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_hUVy8K1b, HV_BINOP_MAX, 1, m, &cBinop_hUVy8K1b_sendMessage);
}

void Heavy_ChaffVerb::cBinop_hUVy8K1b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WUjBnVlx, HV_BINOP_SUBTRACT, 1, m, &cBinop_WUjBnVlx_sendMessage);
}

void Heavy_ChaffVerb::cCast_Up1fincS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_s1DDvTxv, 0, m, &cDelay_s1DDvTxv_sendMessage);
}

void Heavy_ChaffVerb::cBinop_WEB8q0pA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_s1DDvTxv, 2, m, &cDelay_s1DDvTxv_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DXohTEqV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_WEB8q0pA_sendMessage);
}

void Heavy_ChaffVerb::cCast_unzqdP4S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_U8HPWcfs, 0, m, &cVar_U8HPWcfs_sendMessage);
  cMsg_XUaPpWxe_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_mB8eGBnS, 0, m, &cTabhead_mB8eGBnS_sendMessage);
}

void Heavy_ChaffVerb::cMsg_bThkrMD0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_46hLJSab_sendMessage);
}

void Heavy_ChaffVerb::cSystem_46hLJSab_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_UyEwcV5E_sendMessage);
}

void Heavy_ChaffVerb::cDelay_SjpArpzY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_SjpArpzY, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BxilP7rm, 0, m, &cDelay_BxilP7rm_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_SjpArpzY, 0, m, &cDelay_SjpArpzY_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_uqn6ZC3h, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_BxilP7rm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BxilP7rm, m);
  cMsg_APJUyDu5_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_E1TEIKQ6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_j32z2IOr_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_MfNMjCj5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_l62B7lzA_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_lwJzjTGw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IbOfPV1B_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_SjpArpzY, 2, m, &cDelay_SjpArpzY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kbudFOiU_sendMessage);
}

void Heavy_ChaffVerb::cMsg_l62B7lzA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_lwJzjTGw, 0, m, &hTable_lwJzjTGw_sendMessage);
}

void Heavy_ChaffVerb::cBinop_UyEwcV5E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 25.796f, 0, m, &cBinop_MfNMjCj5_sendMessage);
}

void Heavy_ChaffVerb::cMsg_APJUyDu5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_lwJzjTGw, 0, m, &hTable_lwJzjTGw_sendMessage);
}

void Heavy_ChaffVerb::cCast_kbudFOiU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_SjpArpzY, 0, m, &cDelay_SjpArpzY_sendMessage);
}

void Heavy_ChaffVerb::cMsg_IbOfPV1B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_BxilP7rm, 2, m, &cDelay_BxilP7rm_sendMessage);
}

void Heavy_ChaffVerb::cMsg_j32z2IOr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_uqn6ZC3h, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_1TJUXeJg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_36kgowr5, HV_BINOP_SUBTRACT, 0, m, &cBinop_36kgowr5_sendMessage);
}

void Heavy_ChaffVerb::cMsg_CNaEOk8Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_m0d4AX2x_sendMessage);
}

void Heavy_ChaffVerb::cSystem_m0d4AX2x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_aDU8T5lD_sendMessage);
}

void Heavy_ChaffVerb::cVar_qvyAAzqM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tblfE2u3_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_yfArtpXF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_yfArtpXF, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_peJTvmDJ, 0, m, &cDelay_peJTvmDJ_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_jJ7PExKm, 0, m, &sTabread_jJ7PExKm_sendMessage);
}

void Heavy_ChaffVerb::cDelay_peJTvmDJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_peJTvmDJ, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_jJ7PExKm, 0, m, &sTabread_jJ7PExKm_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_peJTvmDJ, 0, m, &cDelay_peJTvmDJ_sendMessage);
}

void Heavy_ChaffVerb::sTabread_jJ7PExKm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_MEI5mx6M, HV_BINOP_SUBTRACT, 0, m, &cBinop_MEI5mx6M_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_065IAkUf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PkQzA3Cu, HV_BINOP_MAX, 0, m, &cBinop_PkQzA3Cu_sendMessage);
}

void Heavy_ChaffVerb::cBinop_aDU8T5lD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_065IAkUf, HV_BINOP_MULTIPLY, 0, m, &cBinop_065IAkUf_sendMessage);
}

void Heavy_ChaffVerb::cBinop_36kgowr5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gZpDhNyN_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_jJ7PExKm, 0, m, &sTabread_jJ7PExKm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fHCTgBcP_sendMessage);
}

void Heavy_ChaffVerb::cSystem_N9Np2ibZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MEI5mx6M, HV_BINOP_SUBTRACT, 1, m, &cBinop_MEI5mx6M_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_peJTvmDJ, 2, m, &cDelay_peJTvmDJ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_tblfE2u3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_N9Np2ibZ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_gZpDhNyN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_yfArtpXF, 0, m, &cDelay_yfArtpXF_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_peJTvmDJ, 0, m, &cDelay_peJTvmDJ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_o6F3LKEg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_PkQzA3Cu, HV_BINOP_MAX, 1, m, &cBinop_PkQzA3Cu_sendMessage);
}

void Heavy_ChaffVerb::cBinop_PkQzA3Cu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_36kgowr5, HV_BINOP_SUBTRACT, 1, m, &cBinop_36kgowr5_sendMessage);
}

void Heavy_ChaffVerb::cCast_fHCTgBcP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_yfArtpXF, 0, m, &cDelay_yfArtpXF_sendMessage);
}

void Heavy_ChaffVerb::cBinop_xaNhHOVv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_yfArtpXF, 2, m, &cDelay_yfArtpXF_sendMessage);
}

void Heavy_ChaffVerb::cBinop_MEI5mx6M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_xaNhHOVv_sendMessage);
}

void Heavy_ChaffVerb::cCast_S7wJPOf1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qvyAAzqM, 0, m, &cVar_qvyAAzqM_sendMessage);
  cMsg_CNaEOk8Q_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_1TJUXeJg, 0, m, &cTabhead_1TJUXeJg_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ApnEGHiw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_6DeMzKpQ_sendMessage);
}

void Heavy_ChaffVerb::cSystem_6DeMzKpQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_f3IuDBXw_sendMessage);
}

void Heavy_ChaffVerb::cDelay_uDPesG5P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_uDPesG5P, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_a21bHihM, 0, m, &cDelay_a21bHihM_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_uDPesG5P, 0, m, &cDelay_uDPesG5P_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_qCypALpj, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_a21bHihM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_a21bHihM, m);
  cMsg_OMNjjemh_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_QvdnUxfr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_er7R39l2_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_bFziMXl4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_drPuIEIr_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_UQoOOfNl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_E4L2Bfoz_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_uDPesG5P, 2, m, &cDelay_uDPesG5P_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YsZjuHKw_sendMessage);
}

void Heavy_ChaffVerb::cMsg_drPuIEIr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_UQoOOfNl, 0, m, &hTable_UQoOOfNl_sendMessage);
}

void Heavy_ChaffVerb::cBinop_f3IuDBXw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 19.392f, 0, m, &cBinop_bFziMXl4_sendMessage);
}

void Heavy_ChaffVerb::cMsg_OMNjjemh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_UQoOOfNl, 0, m, &hTable_UQoOOfNl_sendMessage);
}

void Heavy_ChaffVerb::cCast_YsZjuHKw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_uDPesG5P, 0, m, &cDelay_uDPesG5P_sendMessage);
}

void Heavy_ChaffVerb::cMsg_E4L2Bfoz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_a21bHihM, 2, m, &cDelay_a21bHihM_sendMessage);
}

void Heavy_ChaffVerb::cMsg_er7R39l2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_qCypALpj, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_JSFERbKd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kwBnG3Jg, HV_BINOP_SUBTRACT, 0, m, &cBinop_kwBnG3Jg_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Zb5uYRQU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_lHUpcQfr_sendMessage);
}

void Heavy_ChaffVerb::cSystem_lHUpcQfr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_7Wz2n0c8_sendMessage);
}

void Heavy_ChaffVerb::cVar_z4fVGBv1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7cl3Pibs_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_0RW1uMai_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_0RW1uMai, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_iJLxFRuL, 0, m, &cDelay_iJLxFRuL_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_ZIYbmxfc, 0, m, &sTabread_ZIYbmxfc_sendMessage);
}

void Heavy_ChaffVerb::cDelay_iJLxFRuL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_iJLxFRuL, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_ZIYbmxfc, 0, m, &sTabread_ZIYbmxfc_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_iJLxFRuL, 0, m, &cDelay_iJLxFRuL_sendMessage);
}

void Heavy_ChaffVerb::sTabread_ZIYbmxfc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_5VDv1s9d, HV_BINOP_SUBTRACT, 0, m, &cBinop_5VDv1s9d_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_Q7u3kEnX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QMTLpgeQ, HV_BINOP_MAX, 0, m, &cBinop_QMTLpgeQ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_7Wz2n0c8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Q7u3kEnX, HV_BINOP_MULTIPLY, 0, m, &cBinop_Q7u3kEnX_sendMessage);
}

void Heavy_ChaffVerb::cBinop_kwBnG3Jg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HykXzUF6_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_ZIYbmxfc, 0, m, &sTabread_ZIYbmxfc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oIXB3rJS_sendMessage);
}

void Heavy_ChaffVerb::cSystem_r62tlQEJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5VDv1s9d, HV_BINOP_SUBTRACT, 1, m, &cBinop_5VDv1s9d_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_iJLxFRuL, 2, m, &cDelay_iJLxFRuL_sendMessage);
}

void Heavy_ChaffVerb::cMsg_7cl3Pibs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_r62tlQEJ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_HykXzUF6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_0RW1uMai, 0, m, &cDelay_0RW1uMai_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_iJLxFRuL, 0, m, &cDelay_iJLxFRuL_sendMessage);
}

void Heavy_ChaffVerb::cMsg_S6hdvgi7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_QMTLpgeQ, HV_BINOP_MAX, 1, m, &cBinop_QMTLpgeQ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_QMTLpgeQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kwBnG3Jg, HV_BINOP_SUBTRACT, 1, m, &cBinop_kwBnG3Jg_sendMessage);
}

void Heavy_ChaffVerb::cCast_oIXB3rJS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_0RW1uMai, 0, m, &cDelay_0RW1uMai_sendMessage);
}

void Heavy_ChaffVerb::cBinop_fRxSN3pl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_0RW1uMai, 2, m, &cDelay_0RW1uMai_sendMessage);
}

void Heavy_ChaffVerb::cBinop_5VDv1s9d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_fRxSN3pl_sendMessage);
}

void Heavy_ChaffVerb::cCast_iQ877nBD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_z4fVGBv1, 0, m, &cVar_z4fVGBv1_sendMessage);
  cMsg_Zb5uYRQU_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_JSFERbKd, 0, m, &cTabhead_JSFERbKd_sendMessage);
}

void Heavy_ChaffVerb::cMsg_4EC51hSK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_T3c4i16Q_sendMessage);
}

void Heavy_ChaffVerb::cSystem_T3c4i16Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_jd0SrLcD_sendMessage);
}

void Heavy_ChaffVerb::cDelay_xC6epfaf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xC6epfaf, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_K38BUORK, 0, m, &cDelay_K38BUORK_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xC6epfaf, 0, m, &cDelay_xC6epfaf_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_dlW0w2uZ, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_K38BUORK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_K38BUORK, m);
  cMsg_iEMWVPLl_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_IjzRildJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_SC5BHhWj_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_cO0OuP71_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ExdNFEQp_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_OQfvzmDE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ESV34sLo_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xC6epfaf, 2, m, &cDelay_xC6epfaf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3LXQ63Le_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ExdNFEQp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_OQfvzmDE, 0, m, &hTable_OQfvzmDE_sendMessage);
}

void Heavy_ChaffVerb::cBinop_jd0SrLcD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 16.364f, 0, m, &cBinop_cO0OuP71_sendMessage);
}

void Heavy_ChaffVerb::cMsg_iEMWVPLl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_OQfvzmDE, 0, m, &hTable_OQfvzmDE_sendMessage);
}

void Heavy_ChaffVerb::cCast_3LXQ63Le_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xC6epfaf, 0, m, &cDelay_xC6epfaf_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ESV34sLo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_K38BUORK, 2, m, &cDelay_K38BUORK_sendMessage);
}

void Heavy_ChaffVerb::cMsg_SC5BHhWj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_dlW0w2uZ, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_O74lDE49_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZgiIPrvp, HV_BINOP_SUBTRACT, 0, m, &cBinop_ZgiIPrvp_sendMessage);
}

void Heavy_ChaffVerb::cMsg_zoJBKtPz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_mVZR73hl_sendMessage);
}

void Heavy_ChaffVerb::cSystem_mVZR73hl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Vbm72ZUc_sendMessage);
}

void Heavy_ChaffVerb::cVar_iR2BdYa7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZgK79SVm_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_UCXc16UB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UCXc16UB, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_G2G4Cf9u, 0, m, &cDelay_G2G4Cf9u_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_yxZVGmQe, 0, m, &sTabread_yxZVGmQe_sendMessage);
}

void Heavy_ChaffVerb::cDelay_G2G4Cf9u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_G2G4Cf9u, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_yxZVGmQe, 0, m, &sTabread_yxZVGmQe_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_G2G4Cf9u, 0, m, &cDelay_G2G4Cf9u_sendMessage);
}

void Heavy_ChaffVerb::sTabread_yxZVGmQe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_GJ0TEmla, HV_BINOP_SUBTRACT, 0, m, &cBinop_GJ0TEmla_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_SUvLmU5D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QJg3ewDy, HV_BINOP_MAX, 0, m, &cBinop_QJg3ewDy_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Vbm72ZUc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SUvLmU5D, HV_BINOP_MULTIPLY, 0, m, &cBinop_SUvLmU5D_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ZgiIPrvp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_O1fsBRLJ_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_yxZVGmQe, 0, m, &sTabread_yxZVGmQe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BkLsuyd9_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Lb5VkZyU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GJ0TEmla, HV_BINOP_SUBTRACT, 1, m, &cBinop_GJ0TEmla_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_G2G4Cf9u, 2, m, &cDelay_G2G4Cf9u_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ZgK79SVm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Lb5VkZyU_sendMessage);
}

void Heavy_ChaffVerb::cMsg_O1fsBRLJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_UCXc16UB, 0, m, &cDelay_UCXc16UB_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_G2G4Cf9u, 0, m, &cDelay_G2G4Cf9u_sendMessage);
}

void Heavy_ChaffVerb::cMsg_t8YgegOv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_QJg3ewDy, HV_BINOP_MAX, 1, m, &cBinop_QJg3ewDy_sendMessage);
}

void Heavy_ChaffVerb::cBinop_QJg3ewDy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZgiIPrvp, HV_BINOP_SUBTRACT, 1, m, &cBinop_ZgiIPrvp_sendMessage);
}

void Heavy_ChaffVerb::cCast_BkLsuyd9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_UCXc16UB, 0, m, &cDelay_UCXc16UB_sendMessage);
}

void Heavy_ChaffVerb::cBinop_j6GhnftQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_UCXc16UB, 2, m, &cDelay_UCXc16UB_sendMessage);
}

void Heavy_ChaffVerb::cBinop_GJ0TEmla_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_j6GhnftQ_sendMessage);
}

void Heavy_ChaffVerb::cCast_Pmci1qtV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iR2BdYa7, 0, m, &cVar_iR2BdYa7_sendMessage);
  cMsg_zoJBKtPz_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_O74lDE49, 0, m, &cTabhead_O74lDE49_sendMessage);
}

void Heavy_ChaffVerb::cMsg_R1L2GIwd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_3IEpWJyP_sendMessage);
}

void Heavy_ChaffVerb::cSystem_3IEpWJyP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_nOFQrdIZ_sendMessage);
}

void Heavy_ChaffVerb::cDelay_2fzdfwpd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2fzdfwpd, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_EkJVcAly, 0, m, &cDelay_EkJVcAly_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2fzdfwpd, 0, m, &cDelay_2fzdfwpd_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_dKmFcwEG, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_EkJVcAly_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_EkJVcAly, m);
  cMsg_roejDsT9_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_gJbqui1i_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_plOLXp6K_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_33BAYXTZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2A9scLC5_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_VrejEx9y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_G2Ymjl5t_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2fzdfwpd, 2, m, &cDelay_2fzdfwpd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_u4vtG0lr_sendMessage);
}

void Heavy_ChaffVerb::cMsg_2A9scLC5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_VrejEx9y, 0, m, &hTable_VrejEx9y_sendMessage);
}

void Heavy_ChaffVerb::cBinop_nOFQrdIZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 4.2546f, 0, m, &cBinop_33BAYXTZ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_roejDsT9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_VrejEx9y, 0, m, &hTable_VrejEx9y_sendMessage);
}

void Heavy_ChaffVerb::cCast_u4vtG0lr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_2fzdfwpd, 0, m, &cDelay_2fzdfwpd_sendMessage);
}

void Heavy_ChaffVerb::cMsg_G2Ymjl5t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_EkJVcAly, 2, m, &cDelay_EkJVcAly_sendMessage);
}

void Heavy_ChaffVerb::cMsg_plOLXp6K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_dKmFcwEG, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_jLXcF4l0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ze1ELsCi, HV_BINOP_SUBTRACT, 0, m, &cBinop_ze1ELsCi_sendMessage);
}

void Heavy_ChaffVerb::cMsg_dFHN4rGf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0GsehIZX_sendMessage);
}

void Heavy_ChaffVerb::cSystem_0GsehIZX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_RQtrNqrB_sendMessage);
}

void Heavy_ChaffVerb::cVar_v9ywEZeh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BthXbMCf_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_nDO3tAaP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_nDO3tAaP, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_mhwQeGKe, 0, m, &cDelay_mhwQeGKe_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_FWINubFZ, 0, m, &sTabread_FWINubFZ_sendMessage);
}

void Heavy_ChaffVerb::cDelay_mhwQeGKe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_mhwQeGKe, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_FWINubFZ, 0, m, &sTabread_FWINubFZ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_mhwQeGKe, 0, m, &cDelay_mhwQeGKe_sendMessage);
}

void Heavy_ChaffVerb::sTabread_FWINubFZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_V90zDXP3, HV_BINOP_SUBTRACT, 0, m, &cBinop_V90zDXP3_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_siJVlw0A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yUvBILqm, HV_BINOP_MAX, 0, m, &cBinop_yUvBILqm_sendMessage);
}

void Heavy_ChaffVerb::cBinop_RQtrNqrB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_siJVlw0A, HV_BINOP_MULTIPLY, 0, m, &cBinop_siJVlw0A_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ze1ELsCi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_W6UX3T96_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_FWINubFZ, 0, m, &sTabread_FWINubFZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_z1NHsz7m_sendMessage);
}

void Heavy_ChaffVerb::cSystem_A0B0lmjX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V90zDXP3, HV_BINOP_SUBTRACT, 1, m, &cBinop_V90zDXP3_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_mhwQeGKe, 2, m, &cDelay_mhwQeGKe_sendMessage);
}

void Heavy_ChaffVerb::cMsg_BthXbMCf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_A0B0lmjX_sendMessage);
}

void Heavy_ChaffVerb::cMsg_W6UX3T96_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_nDO3tAaP, 0, m, &cDelay_nDO3tAaP_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_mhwQeGKe, 0, m, &cDelay_mhwQeGKe_sendMessage);
}

void Heavy_ChaffVerb::cMsg_LroctHPY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_yUvBILqm, HV_BINOP_MAX, 1, m, &cBinop_yUvBILqm_sendMessage);
}

void Heavy_ChaffVerb::cBinop_yUvBILqm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ze1ELsCi, HV_BINOP_SUBTRACT, 1, m, &cBinop_ze1ELsCi_sendMessage);
}

void Heavy_ChaffVerb::cCast_z1NHsz7m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_nDO3tAaP, 0, m, &cDelay_nDO3tAaP_sendMessage);
}

void Heavy_ChaffVerb::cBinop_djhOWEdx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_nDO3tAaP, 2, m, &cDelay_nDO3tAaP_sendMessage);
}

void Heavy_ChaffVerb::cBinop_V90zDXP3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_djhOWEdx_sendMessage);
}

void Heavy_ChaffVerb::cCast_eahemivZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_v9ywEZeh, 0, m, &cVar_v9ywEZeh_sendMessage);
  cMsg_dFHN4rGf_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_jLXcF4l0, 0, m, &cTabhead_jLXcF4l0_sendMessage);
}

void Heavy_ChaffVerb::cMsg_hFDHXmBs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_pjoi4qCF_sendMessage);
}

void Heavy_ChaffVerb::cSystem_pjoi4qCF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_lOT40ikm_sendMessage);
}

void Heavy_ChaffVerb::cDelay_WQIw8jhD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_WQIw8jhD, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FcXrjCxC, 0, m, &cDelay_FcXrjCxC_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_WQIw8jhD, 0, m, &cDelay_WQIw8jhD_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_C1x6jfsH, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_FcXrjCxC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_FcXrjCxC, m);
  cMsg_X8PRXeD2_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_ov7Le00M_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_vHnLdKp1_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_3VgOpELT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mWj9mzgx_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_TFIvtNDB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_r0xtZCpA_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_WQIw8jhD, 2, m, &cDelay_WQIw8jhD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_79Hfjl6S_sendMessage);
}

void Heavy_ChaffVerb::cMsg_mWj9mzgx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_TFIvtNDB, 0, m, &hTable_TFIvtNDB_sendMessage);
}

void Heavy_ChaffVerb::cBinop_lOT40ikm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 7.645f, 0, m, &cBinop_3VgOpELT_sendMessage);
}

void Heavy_ChaffVerb::cMsg_X8PRXeD2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_TFIvtNDB, 0, m, &hTable_TFIvtNDB_sendMessage);
}

void Heavy_ChaffVerb::cCast_79Hfjl6S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_WQIw8jhD, 0, m, &cDelay_WQIw8jhD_sendMessage);
}

void Heavy_ChaffVerb::cMsg_r0xtZCpA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_FcXrjCxC, 2, m, &cDelay_FcXrjCxC_sendMessage);
}

void Heavy_ChaffVerb::cMsg_vHnLdKp1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_C1x6jfsH, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_UbpWbCAs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_w16dV3GY, HV_BINOP_SUBTRACT, 0, m, &cBinop_w16dV3GY_sendMessage);
}

void Heavy_ChaffVerb::cMsg_sIikIuuY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Mplf7lA4_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Mplf7lA4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_I1WW3dla_sendMessage);
}

void Heavy_ChaffVerb::cVar_IdUrbUg3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xr0XRMaV_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_dK2gfBCv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dK2gfBCv, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qHJVjmFc, 0, m, &cDelay_qHJVjmFc_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_0Yp78Vy2, 0, m, &sTabread_0Yp78Vy2_sendMessage);
}

void Heavy_ChaffVerb::cDelay_qHJVjmFc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_qHJVjmFc, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_0Yp78Vy2, 0, m, &sTabread_0Yp78Vy2_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qHJVjmFc, 0, m, &cDelay_qHJVjmFc_sendMessage);
}

void Heavy_ChaffVerb::sTabread_0Yp78Vy2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_QqZXy9NC, HV_BINOP_SUBTRACT, 0, m, &cBinop_QqZXy9NC_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_omrsohxL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NUNnpmCm, HV_BINOP_MAX, 0, m, &cBinop_NUNnpmCm_sendMessage);
}

void Heavy_ChaffVerb::cBinop_I1WW3dla_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_omrsohxL, HV_BINOP_MULTIPLY, 0, m, &cBinop_omrsohxL_sendMessage);
}

void Heavy_ChaffVerb::cBinop_w16dV3GY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BLQZDrfR_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_0Yp78Vy2, 0, m, &sTabread_0Yp78Vy2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZTKJHYrt_sendMessage);
}

void Heavy_ChaffVerb::cSystem_DXYxHAXy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QqZXy9NC, HV_BINOP_SUBTRACT, 1, m, &cBinop_QqZXy9NC_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qHJVjmFc, 2, m, &cDelay_qHJVjmFc_sendMessage);
}

void Heavy_ChaffVerb::cMsg_xr0XRMaV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_DXYxHAXy_sendMessage);
}

void Heavy_ChaffVerb::cMsg_BLQZDrfR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_dK2gfBCv, 0, m, &cDelay_dK2gfBCv_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qHJVjmFc, 0, m, &cDelay_qHJVjmFc_sendMessage);
}

void Heavy_ChaffVerb::cMsg_B7Nm3C9S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_NUNnpmCm, HV_BINOP_MAX, 1, m, &cBinop_NUNnpmCm_sendMessage);
}

void Heavy_ChaffVerb::cBinop_NUNnpmCm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_w16dV3GY, HV_BINOP_SUBTRACT, 1, m, &cBinop_w16dV3GY_sendMessage);
}

void Heavy_ChaffVerb::cCast_ZTKJHYrt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_dK2gfBCv, 0, m, &cDelay_dK2gfBCv_sendMessage);
}

void Heavy_ChaffVerb::cBinop_oc4qFEIp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_dK2gfBCv, 2, m, &cDelay_dK2gfBCv_sendMessage);
}

void Heavy_ChaffVerb::cBinop_QqZXy9NC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_oc4qFEIp_sendMessage);
}

void Heavy_ChaffVerb::cCast_lrUaZY9v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IdUrbUg3, 0, m, &cVar_IdUrbUg3_sendMessage);
  cMsg_sIikIuuY_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_UbpWbCAs, 0, m, &cTabhead_UbpWbCAs_sendMessage);
}

void Heavy_ChaffVerb::cVar_OmyZeat0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LVg039Zy, 0, m, &cVar_LVg039Zy_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WQqzeUI6, 0, m, &cVar_WQqzeUI6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_VoWNtNBn, 0, m, &cVar_VoWNtNBn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0Ql1vxro, 0, m, &cVar_0Ql1vxro_sendMessage);
}

void Heavy_ChaffVerb::cVar_BFqUkZdt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.01f, 0, m, &cBinop_JqIaNqpQ_sendMessage);
}

void Heavy_ChaffVerb::cPack_vUzxNa7Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_h4wmVr7S, 0, m, NULL);
}

void Heavy_ChaffVerb::cVar_WQqzeUI6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OfsniVMN, HV_BINOP_MULTIPLY, 0, m, &cBinop_OfsniVMN_sendMessage);
}

void Heavy_ChaffVerb::cMsg_LiqpmzEC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_QnLoHGVd_sendMessage);
}

void Heavy_ChaffVerb::cSystem_QnLoHGVd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XfOaQxjK_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_OfsniVMN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_jcoTG8sg_sendMessage);
}

void Heavy_ChaffVerb::cBinop_TJppsHQF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OfsniVMN, HV_BINOP_MULTIPLY, 1, m, &cBinop_OfsniVMN_sendMessage);
}

void Heavy_ChaffVerb::cMsg_XfOaQxjK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_TJppsHQF_sendMessage);
}

void Heavy_ChaffVerb::cBinop_jcoTG8sg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_8Lky5BRt_sendMessage);
}

void Heavy_ChaffVerb::cBinop_8Lky5BRt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_yUt8Ss5U_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_rpVvtY5w, m);
}

void Heavy_ChaffVerb::cBinop_yUt8Ss5U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_FqY9qwzt, m);
}

void Heavy_ChaffVerb::cVar_VoWNtNBn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_f8HzUKSE, HV_BINOP_MULTIPLY, 0, m, &cBinop_f8HzUKSE_sendMessage);
}

void Heavy_ChaffVerb::cMsg_PERHAfq8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_trSBNttt_sendMessage);
}

void Heavy_ChaffVerb::cSystem_trSBNttt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CcANPeJL_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_f8HzUKSE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_DJYfSx45_sendMessage);
}

void Heavy_ChaffVerb::cBinop_BJdxgGbq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_f8HzUKSE, HV_BINOP_MULTIPLY, 1, m, &cBinop_f8HzUKSE_sendMessage);
}

void Heavy_ChaffVerb::cMsg_CcANPeJL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_BJdxgGbq_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DJYfSx45_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_dnDJm33E_sendMessage);
}

void Heavy_ChaffVerb::cBinop_dnDJm33E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_o2K94SbH_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_QLavkFjC, m);
}

void Heavy_ChaffVerb::cBinop_o2K94SbH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_d9eekS1V, m);
}

void Heavy_ChaffVerb::cVar_0Ql1vxro_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zJpwbBRX, HV_BINOP_MULTIPLY, 0, m, &cBinop_zJpwbBRX_sendMessage);
}

void Heavy_ChaffVerb::cMsg_N4rV1kKS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_qDh9pSDY_sendMessage);
}

void Heavy_ChaffVerb::cSystem_qDh9pSDY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JUI7gGTb_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_zJpwbBRX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_qZI8k37r_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Zwm6ogBM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zJpwbBRX, HV_BINOP_MULTIPLY, 1, m, &cBinop_zJpwbBRX_sendMessage);
}

void Heavy_ChaffVerb::cMsg_JUI7gGTb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Zwm6ogBM_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qZI8k37r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_SoieggwP_sendMessage);
}

void Heavy_ChaffVerb::cBinop_SoieggwP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_pHd0juSs_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_ARZ35i2H, m);
}

void Heavy_ChaffVerb::cBinop_pHd0juSs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_cSCNr5LN, m);
}

void Heavy_ChaffVerb::cBinop_QGvGkjGn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_2bA5qlVC, 0, m, &cPack_2bA5qlVC_sendMessage);
}

void Heavy_ChaffVerb::cMsg_qV7pLj5S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3000.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_OmyZeat0, 0, m, &cVar_OmyZeat0_sendMessage);
}

void Heavy_ChaffVerb::cBinop_JqIaNqpQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_vUzxNa7Q, 0, m, &cPack_vUzxNa7Q_sendMessage);
}

void Heavy_ChaffVerb::cBinop_MFFYqgne_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_YycXJJha, 0, m, &cPack_YycXJJha_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_izVCusjt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_EvZjk8eg_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_EvZjk8eg_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GI5SB8Fq_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cDelay_zMPQ7yMT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zMPQ7yMT, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zMPQ7yMT, 0, m, &cDelay_zMPQ7yMT_sendMessage);
  cSwitchcase_HycHHb1A_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_GI5SB8Fq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EvZjk8eg_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zMPQ7yMT, 0, m, &cDelay_zMPQ7yMT_sendMessage);
  cSwitchcase_HycHHb1A_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cMsg_VVFJPxFF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Q8PayyL5_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Q8PayyL5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_LoMWZMdZ_sendMessage);
}

void Heavy_ChaffVerb::cVar_jUq8fEyy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qnmONYi4, HV_BINOP_MULTIPLY, 0, m, &cBinop_qnmONYi4_sendMessage);
}

void Heavy_ChaffVerb::cMsg_EvZjk8eg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_zMPQ7yMT, 0, m, &cDelay_zMPQ7yMT_sendMessage);
}

void Heavy_ChaffVerb::cBinop_yIFpWtyG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zMPQ7yMT, 2, m, &cDelay_zMPQ7yMT_sendMessage);
}

void Heavy_ChaffVerb::cBinop_LoMWZMdZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qnmONYi4, HV_BINOP_MULTIPLY, 1, m, &cBinop_qnmONYi4_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qnmONYi4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_yIFpWtyG_sendMessage);
}

void Heavy_ChaffVerb::cVar_YhdzLPtL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MOD_UNIPOLAR, 628.0f, 0, m, &cBinop_PHX7YZ7d_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 2.0f, 0, m, &cBinop_S4XgtMpH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_kwhJGtmg_sendMessage);
}

void Heavy_ChaffVerb::cVar_aZFYGOL4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_WTUXBcnl_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_rZqOfbUa, 0, m, &cIf_rZqOfbUa_sendMessage);
}

void Heavy_ChaffVerb::cUnop_SGOeZOhi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0LRjEbnW, HV_BINOP_MOD_UNIPOLAR, 1, m, &cBinop_0LRjEbnW_sendMessage);
}

void Heavy_ChaffVerb::cUnop_0pvjv2yC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0LRjEbnW, HV_BINOP_MOD_UNIPOLAR, 1, m, &cBinop_0LRjEbnW_sendMessage);
}

void Heavy_ChaffVerb::cIf_rZqOfbUa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_0pvjv2yC_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_SGOeZOhi_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_WTUXBcnl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rZqOfbUa, 1, m, &cIf_rZqOfbUa_sendMessage);
}

void Heavy_ChaffVerb::cMsg_CTlE07af_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Tn0lytK1_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Tn0lytK1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_MDdkm0DN_sendMessage);
}

void Heavy_ChaffVerb::cDelay_xk3laogU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xk3laogU, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_NWcGrMHG, 0, m, &cDelay_NWcGrMHG_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xk3laogU, 0, m, &cDelay_xk3laogU_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_IcRmV8Ph, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_NWcGrMHG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_NWcGrMHG, m);
  cMsg_7XEOSRa6_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_82oilqLU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_bWUe2Yl2_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_wSRmbHbU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hyf4gS9x_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_NpNlKGon_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_p6OGvSx0_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xk3laogU, 2, m, &cDelay_xk3laogU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2EGNMIPt_sendMessage);
}

void Heavy_ChaffVerb::cMsg_hyf4gS9x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_NpNlKGon, 0, m, &hTable_NpNlKGon_sendMessage);
}

void Heavy_ChaffVerb::cBinop_MDdkm0DN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 3000.0f, 0, m, &cBinop_wSRmbHbU_sendMessage);
}

void Heavy_ChaffVerb::cMsg_7XEOSRa6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_NpNlKGon, 0, m, &hTable_NpNlKGon_sendMessage);
}

void Heavy_ChaffVerb::cCast_2EGNMIPt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xk3laogU, 0, m, &cDelay_xk3laogU_sendMessage);
}

void Heavy_ChaffVerb::cMsg_p6OGvSx0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_NWcGrMHG, 2, m, &cDelay_NWcGrMHG_sendMessage);
}

void Heavy_ChaffVerb::cMsg_bWUe2Yl2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_IcRmV8Ph, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_IUQqaRy9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qs0ZNzKE, HV_BINOP_SUBTRACT, 0, m, &cBinop_Qs0ZNzKE_sendMessage);
}

void Heavy_ChaffVerb::cMsg_8FQTrOc6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_qCm3BC35_sendMessage);
}

void Heavy_ChaffVerb::cSystem_qCm3BC35_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_T6wSPXEo_sendMessage);
}

void Heavy_ChaffVerb::cVar_5prN7IYv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Sxf7h75i_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_PJiOm9TI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_PJiOm9TI, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_yfzXyLrh, 0, m, &cDelay_yfzXyLrh_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_zC2hurIb, 0, m, &sTabread_zC2hurIb_sendMessage);
}

void Heavy_ChaffVerb::cDelay_yfzXyLrh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_yfzXyLrh, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_zC2hurIb, 0, m, &sTabread_zC2hurIb_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_yfzXyLrh, 0, m, &cDelay_yfzXyLrh_sendMessage);
}

void Heavy_ChaffVerb::sTabread_zC2hurIb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_LkFDHgTm, HV_BINOP_SUBTRACT, 0, m, &cBinop_LkFDHgTm_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_Jswl3Cab_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yK6Z6Xdn, HV_BINOP_MAX, 0, m, &cBinop_yK6Z6Xdn_sendMessage);
}

void Heavy_ChaffVerb::cBinop_T6wSPXEo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Jswl3Cab, HV_BINOP_MULTIPLY, 0, m, &cBinop_Jswl3Cab_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Qs0ZNzKE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tLEhTGpY_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_zC2hurIb, 0, m, &sTabread_zC2hurIb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_B4FP2ni1_sendMessage);
}

void Heavy_ChaffVerb::cSystem_HMqEUNnx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LkFDHgTm, HV_BINOP_SUBTRACT, 1, m, &cBinop_LkFDHgTm_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_yfzXyLrh, 2, m, &cDelay_yfzXyLrh_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Sxf7h75i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_HMqEUNnx_sendMessage);
}

void Heavy_ChaffVerb::cMsg_tLEhTGpY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_PJiOm9TI, 0, m, &cDelay_PJiOm9TI_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_yfzXyLrh, 0, m, &cDelay_yfzXyLrh_sendMessage);
}

void Heavy_ChaffVerb::cMsg_zQUJvpRJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_yK6Z6Xdn, HV_BINOP_MAX, 1, m, &cBinop_yK6Z6Xdn_sendMessage);
}

void Heavy_ChaffVerb::cBinop_yK6Z6Xdn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qs0ZNzKE, HV_BINOP_SUBTRACT, 1, m, &cBinop_Qs0ZNzKE_sendMessage);
}

void Heavy_ChaffVerb::cCast_B4FP2ni1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_PJiOm9TI, 0, m, &cDelay_PJiOm9TI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_kFLCYIoO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_PJiOm9TI, 2, m, &cDelay_PJiOm9TI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_LkFDHgTm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_kFLCYIoO_sendMessage);
}

void Heavy_ChaffVerb::cCast_0I8KqCCq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5prN7IYv, 0, m, &cVar_5prN7IYv_sendMessage);
  cMsg_8FQTrOc6_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_IUQqaRy9, 0, m, &cTabhead_IUQqaRy9_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_NDcFGJ2y_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fraV82Gm_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_fraV82Gm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kfMbnhIg_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cVar_gAw5Efmi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nxXhdqQc, HV_BINOP_ADD, 0, m, &cBinop_nxXhdqQc_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_vak9SsEn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wG4qY0zO_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_wG4qY0zO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YaEqDzcr_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cVar_IeF8WKaC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_F7wn6FAQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ikaC1rdQ_sendMessage);
}

void Heavy_ChaffVerb::cVar_KnY69inE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WA3kYTMG, 0, m, &cVar_WA3kYTMG_sendMessage);
}

void Heavy_ChaffVerb::cVar_WA3kYTMG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GPohGfZH, HV_BINOP_ADD, 0, m, &cBinop_GPohGfZH_sendMessage);
}

void Heavy_ChaffVerb::cVar_fxaE9vpq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_E1hKMInb, HV_BINOP_ADD, 0, m, &cBinop_E1hKMInb_sendMessage);
}

void Heavy_ChaffVerb::cVar_foJcGGTd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_grG86slH_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_58ZW9mbc, 0, m, &cIf_58ZW9mbc_sendMessage);
}

void Heavy_ChaffVerb::cUnop_A8ICpHcf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_E1hKMInb, HV_BINOP_ADD, 1, m, &cBinop_E1hKMInb_sendMessage);
}

void Heavy_ChaffVerb::cUnop_SJ07mW3H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_E1hKMInb, HV_BINOP_ADD, 1, m, &cBinop_E1hKMInb_sendMessage);
}

void Heavy_ChaffVerb::cIf_58ZW9mbc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_SJ07mW3H_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_A8ICpHcf_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_grG86slH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_58ZW9mbc, 1, m, &cIf_58ZW9mbc_sendMessage);
}

void Heavy_ChaffVerb::cVar_59R8Ii3u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_OAF7EUKO_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_lUXrF3Oi, 0, m, &cIf_lUXrF3Oi_sendMessage);
}

void Heavy_ChaffVerb::cUnop_8oFODdyr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_suL30wVz_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cUnop_0ETmwLSC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_suL30wVz_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cIf_lUXrF3Oi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_0ETmwLSC_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_8oFODdyr_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_OAF7EUKO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lUXrF3Oi, 1, m, &cIf_lUXrF3Oi_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_suL30wVz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_9hWjDD2b, 0, m, &cSlice_9hWjDD2b_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_uLP4MPv6, 0, m, &cSlice_uLP4MPv6_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Wf18NXmU_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jcNXNV1s_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cSlice_9hWjDD2b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_zgVuiF7H, 0, m, &cVar_zgVuiF7H_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_zgVuiF7H, 0, m, &cVar_zgVuiF7H_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cSlice_uLP4MPv6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_xPOTMvFf, HV_BINOP_NEQ, 1, m, &cBinop_xPOTMvFf_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_zgVuiF7H, 1, m, &cVar_zgVuiF7H_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_xPOTMvFf, HV_BINOP_NEQ, 1, m, &cBinop_xPOTMvFf_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_zgVuiF7H, 1, m, &cVar_zgVuiF7H_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cVar_zgVuiF7H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kmAwqT7F_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PRiAvzbv_sendMessage);
}

void Heavy_ChaffVerb::cIf_kGjgWGfy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BGzAxItw_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_no9P8tSl_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cCast_BGzAxItw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xPOTMvFf, HV_BINOP_NEQ, 1, m, &cBinop_xPOTMvFf_sendMessage);
}

void Heavy_ChaffVerb::cCast_no9P8tSl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zgVuiF7H, 0, m, &cVar_zgVuiF7H_sendMessage);
}

void Heavy_ChaffVerb::cBinop_xPOTMvFf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kGjgWGfy, 1, m, &cIf_kGjgWGfy_sendMessage);
}

void Heavy_ChaffVerb::cCast_Wf18NXmU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xPOTMvFf, HV_BINOP_NEQ, 0, m, &cBinop_xPOTMvFf_sendMessage);
}

void Heavy_ChaffVerb::cCast_jcNXNV1s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kGjgWGfy, 0, m, &cIf_kGjgWGfy_sendMessage);
}

void Heavy_ChaffVerb::cIf_RDYFTCpJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_KnY69inE, 0, m, &cVar_KnY69inE_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_zKP2urHc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_RDYFTCpJ, 0, m, &cIf_RDYFTCpJ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_zTdbgkHK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_RDYFTCpJ, 0, m, &cIf_RDYFTCpJ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_7FyueW7f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_RDYFTCpJ, 0, m, &cIf_RDYFTCpJ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_1cfsMPRp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_IeF8WKaC, 0, m, &cVar_IeF8WKaC_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cCast_BNYl8eMr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fxaE9vpq, 0, m, &cVar_fxaE9vpq_sendMessage);
}

void Heavy_ChaffVerb::cMsg_FeiBB6L6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_zKP2urHc, 1, m, &cIf_zKP2urHc_sendMessage);
}

void Heavy_ChaffVerb::cMsg_loB8XIn6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_7FyueW7f, 1, m, &cIf_7FyueW7f_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Bj2jLz2v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_zKP2urHc, 1, m, &cIf_zKP2urHc_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_zTdbgkHK, 1, m, &cIf_zTdbgkHK_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_7FyueW7f, 1, m, &cIf_7FyueW7f_sendMessage);
}

void Heavy_ChaffVerb::cBinop_0yTnxXW4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gAw5Efmi, 0, m, &cVar_gAw5Efmi_sendMessage);
}

void Heavy_ChaffVerb::cBinop_zWC3ScTb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_0yTnxXW4_sendMessage);
}

void Heavy_ChaffVerb::cMsg_YaEqDzcr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_IeF8WKaC, 0, m, &cVar_IeF8WKaC_sendMessage);
}

void Heavy_ChaffVerb::cBinop_0LRjEbnW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mEczP16U, HV_BINOP_MULTIPLY, 0, m, &cBinop_mEczP16U_sendMessage);
}

void Heavy_ChaffVerb::cBinop_kwhJGtmg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0LRjEbnW, HV_BINOP_MOD_UNIPOLAR, 0, m, &cBinop_0LRjEbnW_sendMessage);
}

void Heavy_ChaffVerb::cMsg_fGxHXdjz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_zTdbgkHK, 1, m, &cIf_zTdbgkHK_sendMessage);
}

void Heavy_ChaffVerb::cBinop_E1hKMInb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6qCVfqJn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QNirziww_sendMessage);
}

void Heavy_ChaffVerb::cBinop_IuIrIB46_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HZRlSvUa, 0, m, &cVar_HZRlSvUa_sendMessage);
}

void Heavy_ChaffVerb::cCast_6qCVfqJn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IuIrIB46, HV_BINOP_ADD, 1, m, &cBinop_IuIrIB46_sendMessage);
}

void Heavy_ChaffVerb::cCast_QNirziww_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KnY69inE, 0, m, &cVar_KnY69inE_sendMessage);
}

void Heavy_ChaffVerb::cCast_PRiAvzbv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_qDXTgHkd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_kmAwqT7F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Bj2jLz2v_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_q2s0Ek5t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EmlW1xcy, 0, m, &cVar_EmlW1xcy_sendMessage);
}

void Heavy_ChaffVerb::cBinop_mEczP16U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zTdbgkHK, 0, m, &cIf_zTdbgkHK_sendMessage);
}

void Heavy_ChaffVerb::cBinop_0auKD71l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7FyueW7f, 0, m, &cIf_7FyueW7f_sendMessage);
}

void Heavy_ChaffVerb::cBinop_zwON1LRY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_v9fE2YCx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 3.1415f, 0, m, &cBinop_0auKD71l_sendMessage);
}

void Heavy_ChaffVerb::cBinop_PHX7YZ7d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 314.0f, 0, m, &cBinop_UQ5zoNVs_sendMessage);
}

void Heavy_ChaffVerb::cBinop_UQ5zoNVs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_zwON1LRY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_S4XgtMpH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YhdzLPtL, 1, m, &cVar_YhdzLPtL_sendMessage);
}

void Heavy_ChaffVerb::cBinop_3VOJpJNd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_19ByyUfF, 0, m, &cVar_19ByyUfF_sendMessage);
}

void Heavy_ChaffVerb::cBinop_xfcLJoiD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jUq8fEyy, 0, m, &cVar_jUq8fEyy_sendMessage);
}

void Heavy_ChaffVerb::cMsg_kfMbnhIg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_KnY69inE, 0, m, &cVar_KnY69inE_sendMessage);
}

void Heavy_ChaffVerb::cBinop_nxXhdqQc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TsUsgWBZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_TsUsgWBZ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_TsUsgWBZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1cfsMPRp, 0, m, &cIf_1cfsMPRp_sendMessage);
}

void Heavy_ChaffVerb::cBinop_0jB2bvVX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IuIrIB46, HV_BINOP_ADD, 0, m, &cBinop_IuIrIB46_sendMessage);
}

void Heavy_ChaffVerb::cCast_ikaC1rdQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KnY69inE, 0, m, &cVar_KnY69inE_sendMessage);
}

void Heavy_ChaffVerb::cCast_F7wn6FAQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0jB2bvVX, HV_BINOP_ADD, 1, m, &cBinop_0jB2bvVX_sendMessage);
}

void Heavy_ChaffVerb::cCast_0D1evoLq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RDYFTCpJ, 1, m, &cIf_RDYFTCpJ_sendMessage);
}

void Heavy_ChaffVerb::cCast_gF2ANyGN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_NDcFGJ2y_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_CPzGaWXd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gAw5Efmi, 0, m, &cVar_gAw5Efmi_sendMessage);
}

void Heavy_ChaffVerb::cCast_U1cmsGJK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TsUsgWBZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_TsUsgWBZ_sendMessage);
}

void Heavy_ChaffVerb::cCast_iu4HlLue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_vak9SsEn_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_mWhY59ST_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1cfsMPRp, 1, m, &cIf_1cfsMPRp_sendMessage);
}

void Heavy_ChaffVerb::cCast_FucmKUpZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gAw5Efmi, 0, m, &cVar_gAw5Efmi_sendMessage);
}

void Heavy_ChaffVerb::cCast_QGMySUek_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nxXhdqQc, HV_BINOP_ADD, 1, m, &cBinop_nxXhdqQc_sendMessage);
}

void Heavy_ChaffVerb::cBinop_AN7R2O3h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0jB2bvVX, HV_BINOP_ADD, 0, m, &cBinop_0jB2bvVX_sendMessage);
}

void Heavy_ChaffVerb::cBinop_GPohGfZH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AN7R2O3h, HV_BINOP_MULTIPLY, 0, m, &cBinop_AN7R2O3h_sendMessage);
}

void Heavy_ChaffVerb::cCast_fGbKkObY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KnY69inE, 0, m, &cVar_KnY69inE_sendMessage);
}

void Heavy_ChaffVerb::cCast_EmgT8dZD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AN7R2O3h, HV_BINOP_MULTIPLY, 1, m, &cBinop_AN7R2O3h_sendMessage);
}

void Heavy_ChaffVerb::cCast_kzrR0426_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KnY69inE, 0, m, &cVar_KnY69inE_sendMessage);
}

void Heavy_ChaffVerb::cCast_GUDfZ3pn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GPohGfZH, HV_BINOP_ADD, 1, m, &cBinop_GPohGfZH_sendMessage);
}

void Heavy_ChaffVerb::cMsg_CGPbYBrR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kmAwqT7F_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PRiAvzbv_sendMessage);
}

void Heavy_ChaffVerb::cReceive_PyyMWJsu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rRgk1knQ_sendMessage(_c, 0, m);
  cMsg_bThkrMD0_sendMessage(_c, 0, m);
  cMsg_ApnEGHiw_sendMessage(_c, 0, m);
  cMsg_4EC51hSK_sendMessage(_c, 0, m);
  cMsg_R1L2GIwd_sendMessage(_c, 0, m);
  cMsg_hFDHXmBs_sendMessage(_c, 0, m);
  cMsg_rvQdpH1U_sendMessage(_c, 0, m);
  cMsg_ak8IcJrK_sendMessage(_c, 0, m);
  cMsg_6hq4GrT2_sendMessage(_c, 0, m);
  cMsg_cVxz00gk_sendMessage(_c, 0, m);
  cMsg_uaqeeZFi_sendMessage(_c, 0, m);
  cMsg_i9RXI1pV_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_LVg039Zy, 0, m, &cVar_LVg039Zy_sendMessage);
  cMsg_LiqpmzEC_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_WQqzeUI6, 0, m, &cVar_WQqzeUI6_sendMessage);
  cMsg_PERHAfq8_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_VoWNtNBn, 0, m, &cVar_VoWNtNBn_sendMessage);
  cMsg_N4rV1kKS_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_0Ql1vxro, 0, m, &cVar_0Ql1vxro_sendMessage);
  cMsg_5OcgfgbN_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_2hE7623h, 0, m, &cVar_2hE7623h_sendMessage);
  cMsg_J84fwcle_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_19ByyUfF, 0, m, &cVar_19ByyUfF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_F04CV4Qc, 0, m, &cVar_F04CV4Qc_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_EmlW1xcy, 0, m, &cVar_EmlW1xcy_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_bXzBsHfY, 0, m, &cVar_bXzBsHfY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9VRQfEbG, 0, m, &cVar_9VRQfEbG_sendMessage);
  cMsg_VVFJPxFF_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_jUq8fEyy, 0, m, &cVar_jUq8fEyy_sendMessage);
  cMsg_CTlE07af_sendMessage(_c, 0, m);
  cSwitchcase_YJAt0eez_onMessage(_c, NULL, 0, m, NULL);
  cMsg_kfMbnhIg_sendMessage(_c, 0, m);
  cMsg_CGPbYBrR_sendMessage(_c, 0, m);
  cMsg_YaEqDzcr_sendMessage(_c, 0, m);
  cSwitchcase_izVCusjt_onMessage(_c, NULL, 0, m, NULL);
  cVar_onMessage(_c, &Context(_c)->cVar_YZjX8hmp, 0, m, &cVar_YZjX8hmp_sendMessage);
  cMsg_1qadGV3Q_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_GV12EERs, 0, m, &cVar_GV12EERs_sendMessage);
  cMsg_tMGjiHJf_sendMessage(_c, 0, m);
  cMsg_d7UEgPIY_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_zGjdzP6I, 0, m, &cVar_zGjdzP6I_sendMessage);
  cMsg_iHCjHls0_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_nkRsEUzG, 0, m, &cTabhead_nkRsEUzG_sendMessage);
  cMsg_lciJZgSY_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_l7yxOHqT, 0, m, &cVar_l7yxOHqT_sendMessage);
  cMsg_FSf7GyfT_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_fEDGYWso, 0, m, &cTabhead_fEDGYWso_sendMessage);
  cMsg_H34mlmYC_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_5NxGnck5, 0, m, &cVar_5NxGnck5_sendMessage);
  cMsg_0CRJFHIe_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_7RjnzB0n, 0, m, &cTabhead_7RjnzB0n_sendMessage);
  cMsg_ghGqKZHQ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_QhGLWWzl, 0, m, &cVar_QhGLWWzl_sendMessage);
  cMsg_z5JbvRpw_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_cFqrwKXc, 0, m, &cTabhead_cFqrwKXc_sendMessage);
  cMsg_XY8Rds3D_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_U8HPWcfs, 0, m, &cVar_U8HPWcfs_sendMessage);
  cMsg_XUaPpWxe_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_mB8eGBnS, 0, m, &cTabhead_mB8eGBnS_sendMessage);
  cMsg_o6F3LKEg_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_qvyAAzqM, 0, m, &cVar_qvyAAzqM_sendMessage);
  cMsg_CNaEOk8Q_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_1TJUXeJg, 0, m, &cTabhead_1TJUXeJg_sendMessage);
  cMsg_S6hdvgi7_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_z4fVGBv1, 0, m, &cVar_z4fVGBv1_sendMessage);
  cMsg_Zb5uYRQU_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_JSFERbKd, 0, m, &cTabhead_JSFERbKd_sendMessage);
  cMsg_t8YgegOv_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_iR2BdYa7, 0, m, &cVar_iR2BdYa7_sendMessage);
  cMsg_zoJBKtPz_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_O74lDE49, 0, m, &cTabhead_O74lDE49_sendMessage);
  cMsg_LroctHPY_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_v9ywEZeh, 0, m, &cVar_v9ywEZeh_sendMessage);
  cMsg_dFHN4rGf_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_jLXcF4l0, 0, m, &cTabhead_jLXcF4l0_sendMessage);
  cMsg_B7Nm3C9S_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_IdUrbUg3, 0, m, &cVar_IdUrbUg3_sendMessage);
  cMsg_sIikIuuY_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_UbpWbCAs, 0, m, &cTabhead_UbpWbCAs_sendMessage);
  cMsg_zQUJvpRJ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_5prN7IYv, 0, m, &cVar_5prN7IYv_sendMessage);
  cMsg_8FQTrOc6_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_IUQqaRy9, 0, m, &cTabhead_IUQqaRy9_sendMessage);
}

void Heavy_ChaffVerb::cReceive_7EZsLRIm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 157.0f, 0, m, &cBinop_3VOJpJNd_sendMessage);
}

void Heavy_ChaffVerb::cReceive_iqoTcYmZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_59R8Ii3u, 0, m, &cVar_59R8Ii3u_sendMessage);
}

void Heavy_ChaffVerb::cReceive_XCQD18R8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aZFYGOL4, 0, m, &cVar_aZFYGOL4_sendMessage);
}

void Heavy_ChaffVerb::cReceive_GATK0CxN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mEczP16U, HV_BINOP_MULTIPLY, 1, m, &cBinop_mEczP16U_sendMessage);
}

void Heavy_ChaffVerb::cReceive_eY41Qemk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GUDfZ3pn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kzrR0426_sendMessage);
}

void Heavy_ChaffVerb::cReceive_ODmFsjRj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EmgT8dZD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fGbKkObY_sendMessage);
}

void Heavy_ChaffVerb::cReceive_btGfvAme_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fxaE9vpq, 0, m, &cVar_fxaE9vpq_sendMessage);
}

void Heavy_ChaffVerb::cReceive_22QwyOO1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BNYl8eMr_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_foJcGGTd, 0, m, &cVar_foJcGGTd_sendMessage);
}

void Heavy_ChaffVerb::cReceive_iffMoq8w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 157.0f, 0, m, &cBinop_xfcLJoiD_sendMessage);
}

void Heavy_ChaffVerb::cReceive_4F2uLaUK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QGMySUek_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FucmKUpZ_sendMessage);
}

void Heavy_ChaffVerb::cReceive_JhROtCwj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_U1cmsGJK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CPzGaWXd_sendMessage);
}

void Heavy_ChaffVerb::cReceive_2bCaFxqj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mWhY59ST_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iu4HlLue_sendMessage);
}

void Heavy_ChaffVerb::cReceive_XYQesTDN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_XEB4jDt2, m);
}

void Heavy_ChaffVerb::cReceive_I2QqTtZI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_2OPSV9yg, m);
}

void Heavy_ChaffVerb::cReceive_S0sG2IoD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_F04CV4Qc, 0, m, &cVar_F04CV4Qc_sendMessage);
}

void Heavy_ChaffVerb::cReceive_sD4P3ECJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 100.0f, 0, m, &cBinop_q2s0Ek5t_sendMessage);
}

void Heavy_ChaffVerb::cReceive_ZreJBCML_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4uhoE5nR, 0, m, &cVar_4uhoE5nR_sendMessage);
}

void Heavy_ChaffVerb::cReceive_EruxOk1F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3WsMvqbI, 0, m, &cVar_3WsMvqbI_sendMessage);
}

void Heavy_ChaffVerb::cReceive_tWGDq7C6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2hE7623h, 0, m, &cVar_2hE7623h_sendMessage);
}

void Heavy_ChaffVerb::cReceive_MMEkQhWo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_oIfxBiP6, m);
}

void Heavy_ChaffVerb::cReceive_m3uXQ87J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_jZbszGbo, m);
}

void Heavy_ChaffVerb::cReceive_fqCkZ6ZE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Jswl3Cab, HV_BINOP_MULTIPLY, 1, m, &cBinop_Jswl3Cab_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0I8KqCCq_sendMessage);
}

void Heavy_ChaffVerb::cReceive_mfZmkl1P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0D1evoLq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gF2ANyGN_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_ChaffVerb::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13, Bf14;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_phasor_k_f(&sPhasor_Edfdcaxi, VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf2), VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf4), 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f);
    __hv_var_k_f(VOf(Bf5), 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f);
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf1), VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_1cpZyiXb, VOf(Bf4));
    __hv_line_f(&sLine_E6P7DZ0d, VOf(Bf1));
    __hv_fma_f(VIf(Bf0), VIf(Bf4), VIf(Bf1), VOf(Bf2));
    __hv_tabhead_f(&sTabhead_8RgebfgV, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf6), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_5QEHi7QD, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_d3h77QEQ, VOf(Bf2));
    __hv_min_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf6));
    __hv_varread_f(&sVarf_AtsFugVf, VOf(Bf2));
    __hv_zero_f(VOf(Bf7));
    __hv_lt_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_and_f(VIf(Bf2), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_cast_fi(VIf(Bf7), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_A0E5QkPS, VIi(Bi1), VOf(Bf7));
    __hv_tabread_if(&sTabread_8yEFsUds, VIi(Bi0), VOf(Bf2));
    __hv_sub_f(VIf(Bf7), VIf(Bf2), VOf(Bf7));
    __hv_sub_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf7), VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_add_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_floor_f(VIf(Bf6), VOf(Bf0));
    __hv_sub_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_floor_f(VIf(Bf7), VOf(Bf6));
    __hv_sub_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_abs_f(VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf6), 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f);
    __hv_sub_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f);
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf7), VIf(Bf7), VOf(Bf6));
    __hv_mul_f(VIf(Bf7), VIf(Bf6), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf8), 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f);
    __hv_var_k_f(VOf(Bf9), 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f);
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf6), VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf0), VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_tabhead_f(&sTabhead_lV4ybl91, VOf(Bf4));
    __hv_var_k_f_r(VOf(Bf0), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_QopkJA3T, VOf(Bf4));
    __hv_mul_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_2Wh1pN0p, VOf(Bf1));
    __hv_min_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_zero_f(VOf(Bf4));
    __hv_max_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_floor_f(VIf(Bf4), VOf(Bf0));
    __hv_varread_f(&sVarf_7WsEA8Ie, VOf(Bf1));
    __hv_zero_f(VOf(Bf8));
    __hv_lt_f(VIf(Bf0), VIf(Bf8), VOf(Bf8));
    __hv_and_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf0), VIf(Bf8), VOf(Bf8));
    __hv_cast_fi(VIf(Bf8), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_asi8Lk76, VIi(Bi1), VOf(Bf8));
    __hv_tabread_if(&sTabread_yZ1W6nNx, VIi(Bi0), VOf(Bf1));
    __hv_sub_f(VIf(Bf8), VIf(Bf1), VOf(Bf8));
    __hv_sub_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_fma_f(VIf(Bf8), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_p4H0tNBb, VIf(I0));
    __hv_varread_f(&sVarf_AYADOSxP, VOf(Bf2));
    __hv_rpole_f(&sRPole_RlchLP8I, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_ELV94o3k, VIf(Bf2), VOf(Bf5));
    __hv_mul_f(VIf(Bf5), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_0RK74LDG, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_oIfxBiP6, VOf(Bf1));
    __hv_tabread_f(&sTabread_zC2hurIb, VOf(Bf5));
    __hv_varread_f(&sVarf_jZbszGbo, VOf(Bf9));
    __hv_mul_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_tabwrite_f(&sTabwrite_IcRmV8Ph, VIf(Bf9));
    __hv_varread_f(&sVarf_2OPSV9yg, VOf(Bf9));
    __hv_fma_f(VIf(I0), VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_tabread_f(&sTabread_YdYzQAAo, VOf(Bf9));
    __hv_varread_f(&sVarf_zhSdwg0C, VOf(Bf1));
    __hv_mul_f(VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_jRVRQoZd, VOf(Bf2));
    __hv_rpole_f(&sRPole_msRyLgWs, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf2), VIf(Bf9), VOf(Bf2));
    __hv_line_f(&sLine_h4wmVr7S, VOf(Bf1));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_dun5Gj9V, VOf(Bf2));
    __hv_tabread_f(&sTabread_CoX3wble, VOf(Bf0));
    __hv_add_f(VIf(Bf5), VIf(Bf0), VOf(Bf8));
    __hv_tabread_f(&sTabread_jJ7PExKm, VOf(Bf4));
    __hv_add_f(VIf(Bf8), VIf(Bf4), VOf(Bf6));
    __hv_tabread_f(&sTabread_ZIYbmxfc, VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf3));
    __hv_tabread_f(&sTabread_yxZVGmQe, VOf(Bf10));
    __hv_add_f(VIf(Bf3), VIf(Bf10), VOf(Bf11));
    __hv_tabread_f(&sTabread_0Yp78Vy2, VOf(Bf12));
    __hv_add_f(VIf(Bf11), VIf(Bf12), VOf(Bf13));
    __hv_tabread_f(&sTabread_FWINubFZ, VOf(Bf14));
    __hv_tabwrite_f(&sTabwrite_EyVrZebd, VIf(Bf5));
    __hv_sub_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_uqn6ZC3h, VIf(Bf0));
    __hv_sub_f(VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_tabwrite_f(&sTabwrite_qCypALpj, VIf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_tabwrite_f(&sTabwrite_dlW0w2uZ, VIf(Bf7));
    __hv_sub_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_tabwrite_f(&sTabwrite_dKmFcwEG, VIf(Bf12));
    __hv_sub_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_tabwrite_f(&sTabwrite_C1x6jfsH, VIf(Bf10));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf13), VOf(Bf13));
    __hv_tabread_f(&sTabread_dp5qrxkc, VOf(Bf9));
    __hv_varread_f(&sVarf_rpVvtY5w, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_FqY9qwzt, VOf(Bf3));
    __hv_rpole_f(&sRPole_LVDZeQFQ, VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf3));
    __hv_fma_f(VIf(Bf3), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf13), VIf(Bf14), VOf(Bf9));
    __hv_tabread_f(&sTabread_hwpN1FVr, VOf(Bf3));
    __hv_varread_f(&sVarf_QLavkFjC, VOf(Bf10));
    __hv_mul_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_d9eekS1V, VOf(Bf12));
    __hv_rpole_f(&sRPole_Piz6KqHV, VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_sub_f(VIf(Bf12), VIf(Bf3), VOf(Bf12));
    __hv_fma_f(VIf(Bf12), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf3));
    __hv_tabread_f(&sTabread_bgxyfHM0, VOf(Bf12));
    __hv_varread_f(&sVarf_ARZ35i2H, VOf(Bf10));
    __hv_mul_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_cSCNr5LN, VOf(Bf11));
    __hv_rpole_f(&sRPole_xBjYFzNr, VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_sub_f(VIf(Bf11), VIf(Bf12), VOf(Bf11));
    __hv_fma_f(VIf(Bf11), VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf3), VIf(Bf2), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_72K7vOpf, VIf(Bf1));
    __hv_sub_f(VIf(Bf13), VIf(Bf14), VOf(Bf1));
    __hv_sub_f(VIf(Bf3), VIf(Bf2), VOf(Bf11));
    __hv_add_f(VIf(Bf1), VIf(Bf11), VOf(Bf10));
    __hv_tabwrite_f(&sTabwrite_mLOgGEWK, VIf(Bf10));
    __hv_sub_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_tabwrite_f(&sTabwrite_7QhySYme, VIf(Bf12));
    __hv_sub_f(VIf(Bf1), VIf(Bf11), VOf(Bf11));
    __hv_tabwrite_f(&sTabwrite_voKIXw9m, VIf(Bf11));
    __hv_line_f(&sLine_hny6jqOl, VOf(Bf11));
    __hv_mul_f(VIf(Bf13), VIf(Bf11), VOf(Bf13));
    __hv_mul_f(VIf(Bf14), VIf(Bf11), VOf(Bf14));
    __hv_mul_f(VIf(Bf3), VIf(Bf11), VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_XEB4jDt2, VOf(Bf2));
    __hv_mul_f(VIf(I0), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf13), VIf(Bf2), VOf(Bf13));
    __hv_add_f(VIf(Bf13), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf14), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf11), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_ChaffVerb::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 1 channel(s)
  float **const bIn = &inputBuffers;

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_ChaffVerb::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 1 channel(s), uninterleave
  float *const bIn = inputBuffers;

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
